/*
 *  TOPPERS/ASP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Advanced Standard Profile Kernel
 * 
 *  Copyright (C) 2008-2010 by Witz Corporation, JAPAN
 *  Copyright (C) 2013      by Mitsuhiro Matsuura
 * 
 *  上記著作権者は，以下の(1)～(4)の条件を満たす場合に限り，本ソフトウェ
 *  ア（本ソフトウェアを改変したものを含む．以下同じ）を使用・複製・改
 *  変・再配布（以下，利用と呼ぶ）することを無償で許諾する．
 *  (1) 本ソフトウェアをソースコードの形で利用する場合には，上記の著作
 *      権表示，この利用条件および下記の無保証規定が，そのままの形でソー
 *      スコード中に含まれていること．
 *  (2) 本ソフトウェアを，ライブラリ形式など，他のソフトウェア開発に使
 *      用できる形で再配布する場合には，再配布に伴うドキュメント（利用
 *      者マニュアルなど）に，上記の著作権表示，この利用条件および下記
 *      の無保証規定を掲載すること．
 *  (3) 本ソフトウェアを，機器に組み込むなど，他のソフトウェア開発に使
 *      用できない形で再配布する場合には，次のいずれかの条件を満たすこ
 *      と．
 *    (a) 再配布に伴うドキュメント（利用者マニュアルなど）に，上記の著
 *        作権表示，この利用条件および下記の無保証規定を掲載すること．
 *    (b) 再配布の形態を，別に定める方法によって，TOPPERSプロジェクトに
 *        報告すること．
 *  (4) 本ソフトウェアの利用により直接的または間接的に生じるいかなる損
 *      害からも，上記著作権者およびTOPPERSプロジェクトを免責すること．
 *      また，本ソフトウェアのユーザまたはエンドユーザからのいかなる理
 *      由に基づく請求からも，上記著作権者およびTOPPERSプロジェクトを
 *      免責すること．
 * 
 *  本ソフトウェアは，無保証で提供されているものである．上記著作権者お
 *  よびTOPPERSプロジェクトは，本ソフトウェアに関して，特定の使用目的
 *  に対する適合性も含めて，いかなる保証も行わない．また，本ソフトウェ
 *  アの利用により直接的または間接的に生じたいかなる損害に関しても，そ
 *  の責任を負わない．
 * 
 *  @(#) $Id$
 */

/*
 *  RX630に依存する定義
 */
#ifndef TOPPERS_RX630_H
#define TOPPERS_RX630_H

#define __evenaccess

/*
 *  CPU例外ハンドラ番号の定義(固定ベクタテーブル)
 *
 *  番号の範囲は0 - 31
 */
#define INT_PRIVILEGED_INSTRUNCTION		20		/* 特権命令例外 */
#define INT_UNDEF_INSTRUNCTION			23		/* 未定義命令例外 */
#define INT_FLOATINGPOINT_INSTRUCTION	25		/* 浮動小数点例外 */
#define INT_NMI							30		/* ノンマスカブル割り込み */
#define INT_RESET						31		/* リセット */

/*
 *  割込み番号の定義(可変ベクタテーブル)
 */
#define INT_BUSERR			16
#define INT_FCU_FCUERR		21
#define INT_FCU_FRDYI		23
#define INT_ICU_SWINT		27
#define INT_CMT0_CMI		28
#define INT_CMT1_CMI		29
#define INT_CMT2_CMI		30
#define INT_CMT3_CMI		31
#define INT_ETH_EINT		32
#define INT_USB0_D0FIFO0	33
#define INT_USB0_D1FIFO0	34
#define INT_USB0_USBI0		35
#define INT_USB1_D0FIFO1	36
#define INT_USB1_D1FIFO1	37
#define INT_USB1_USBI1		38
#define INT_RSPI0_SPRI0		39
#define INT_RSPI0_SPTI0		40
#define INT_RSPI0_SPII0		41
#define INT_RSPI1_SPRI1		42
#define INT_RSPI1_SPTI1		43
#define INT_RSPI1_SPII1		44
#define INT_RSPI2_SPRI2		45
#define INT_RSPI2_SPTI2		46
#define INT_RSPI2_SPII2		47
#define INT_CAN0_RXF0		48
#define INT_CAN0_TXF0		49
#define INT_CAN0_RXM0		50
#define INT_CAN0_TXM0		51
#define INT_CAN1_RXF1		52
#define INT_CAN1_TXF1		53
#define INT_CAN1_RXM1		54
#define INT_CAN1_TXM1		55
#define INT_CAN2_RXF2		56
#define INT_CAN2_TXF2		57
#define INT_CAN2_RXM2		58
#define INT_CAN2_TXM2		59
#define INT_RTC_CUP			62
#define INT_IRQ0			64
#define INT_IRQ1			65
#define INT_IRQ2			66
#define INT_IRQ3			67
#define INT_IRQ4			68
#define INT_IRQ5			69
#define INT_IRQ6			70
#define INT_IRQ7			71
#define INT_IRQ8			72
#define INT_IRQ9			73
#define INT_IRQ10			74
#define INT_IRQ11			75
#define INT_IRQ12			76
#define INT_IRQ13			77
#define INT_IRQ14			78
#define INT_IRQ15			79
#define INT_USB_USBR0		90
#define INT_USB_USBR1		91
#define INT_RTC_ALM			92
#define INT_RTC_PRD			93
#define INT_AD0_ADI0		98
#define INT_S12AD_S12ADI0	102
#define INT_ICU_GROUP0		106
#define INT_ICU_GROUP1		107
#define INT_ICU_GROUP2		108
#define INT_ICU_GROUP3		109
#define INT_ICU_GROUP4		110
#define INT_ICU_GROUP5		111
#define INT_ICU_GROUP6		112
#define INT_ICU_GROUP12		114
#define INT_SCI12_SCIX0		122
#define INT_SCI12_SCIX1		123
#define INT_SCI12_SCIX2		124
#define INT_SCI12_SCIX3		125
#define INT_TPU0_TGI0A		126
#define INT_TPU0_TGI0B		127
#define INT_TPU0_TGI0C		128
#define INT_TPU0_TGI0D		129
#define INT_TPU1_TGI0A		130
#define INT_TPU1_TGI0B		131
#define INT_TPU2_TGI0A		132
#define INT_TPU2_TGI0B		133
#define INT_TPU3_TGI0A		134
#define INT_TPU3_TGI0B		135
#define INT_TPU3_TGI0C		136
#define INT_TPU3_TGI0D		137
#define INT_TPU4_TGI0A		138
#define INT_TPU4_TGI0B		139
#define INT_TPU5_TGI0A		140
#define INT_TPU5_TGI0B		141
#define INT_MTU0_TGIA0		142
#define INT_MTU0_TGIB0		143
#define INT_MTU0_TGIC0		144
#define INT_MTU0_TGID0		145
#define INT_MTU0_TCIE0		146
#define INT_MTU0_TCIF0		147
#define INT_MTU1_TGIA1		148
#define INT_MTU1_TGIB1		149
#define INT_MTU2_TGIA2		150
#define INT_MTU2_TGIB2		151
#define INT_MTU3_TGIA3		152
#define INT_MTU3_TGIB3		153
#define INT_MTU3_TGIC3		154
#define INT_MTU3_TGID3		155
#define INT_MTU4_TGIA4		156
#define INT_MTU4_TGIB4		157
#define INT_MTU4_TGIC4		158
#define INT_MTU4_TGID4		159
#define INT_MTU4_TCIV4		160
#define INT_MTU5_TGIU5		161
#define INT_MTU5_TGIV5		162
#define INT_MTU5_TGIW5		163
#define INT_MTU5_TGI11A		164
#define INT_MTU5_TGI11B		165
#define INT_POE_OEI1		166
#define INT_POE_OEI2		167
#define INT_TMR0_CMI0A		170
#define INT_TMR0_CMI0B		171
#define INT_TMR0_OV0I		172
#define INT_TMR1_CMI1A		173
#define INT_TMR1_CMI1B		174
#define INT_TMR1_OV1I		175
#define INT_TMR2_CMI2A		176
#define INT_TMR2_CMI2B		177
#define INT_TMR2_OV2I		178
#define INT_TMR3_CMI3A		179
#define INT_TMR3_CMI3B		180
#define INT_TMR3_OV3I		181
#define INT_RIIC0_EEI		182
#define INT_RIIC0_RXI		183
#define INT_RIIC0_TXI		184
#define INT_RIIC0_TEI		185
#define INT_RIIC1_EEI		186
#define INT_RIIC1_RXI		187
#define INT_RIIC1_TXI		188
#define INT_RIIC1_TEI		189
#define INT_RIIC2_EEI		190
#define INT_RIIC2_RXI		191
#define INT_RIIC2_TXI		192
#define INT_RIIC2_TEI		193
#define INT_RIIC3_EEI		194
#define INT_RIIC3_RXI		195
#define INT_RIIC3_TXI		196
#define INT_RIIC3_TEI		197
#define INT_DMAC_DMAC0I		198
#define INT_DMAC_DMAC1I		199
#define INT_DMAC_DMAC2I		200
#define INT_DMAC_DMAC3I		201
#define INT_SCI0_RXI		214
#define INT_SCI0_TXI		215
#define INT_SCI0_TEI		216
#define INT_SCI1_RXI		217
#define INT_SCI1_TXI		218
#define INT_SCI1_TEI		219
#define INT_SCI2_RXI		220
#define INT_SCI2_TXI		221
#define INT_SCI2_TEI		222
#define INT_SCI3_RXI		223
#define INT_SCI3_TXI		224
#define INT_SCI3_TEI		225
#define INT_SCI4_RXI		226
#define INT_SCI4_TXI		227
#define INT_SCI4_TEI		228
#define INT_SCI5_RXI		229
#define INT_SCI5_TXI		230
#define INT_SCI5_TEI		231
#define INT_SCI6_RXI		232
#define INT_SCI6_TXI		233
#define INT_SCI6_TEI		234
#define INT_SCI7_RXI		235
#define INT_SCI7_TXI		236
#define INT_SCI7_TEI		237
#define INT_SCI8_RXI		238
#define INT_SCI8_TXI		239
#define INT_SCI8_TEI		240
#define INT_SCI9_RXI		241
#define INT_SCI9_TXI		242
#define INT_SCI9_TEI		243
#define INT_SCI10_RXI		244
#define INT_SCI10_TXI		245
#define INT_SCI10_TEI		246
#define INT_SCI11_RXI		247
#define INT_SCI11_TXI		248
#define INT_SCI11_TEI		249
#define INT_SCI12_RXI		250
#define INT_SCI12_TXI		251
#define INT_SCI12_TEI		252
#define INT_IEB_IEBINT		253

/*
 *  各モジュールのレジスタ及び設定ビット情報
 */

#define SYSTEM_SYSCR0_ADDR		( ( volatile uint16_t __evenaccess * )0x00080006 )

/*
 * モジュールストップコントロールレジスタA（MSTPCRA）
 */
#define SYSTEM_MSTPCRA_ADDR			( ( volatile uint32_t __evenaccess * )0x00080010 )
#define SYSTEM_MSTPCRA_MSTPA0_BIT	( 1UL << 0U )
#define SYSTEM_MSTPCRA_MSTPA1_BIT	( 1UL << 1U )
#define SYSTEM_MSTPCRA_MSTPA2_BIT	( 1UL << 2U )
#define SYSTEM_MSTPCRA_MSTPA3_BIT	( 1UL << 3U )
#define SYSTEM_MSTPCRA_MSTPA4_BIT	( 1UL << 4U )
#define SYSTEM_MSTPCRA_MSTPA5_BIT	( 1UL << 5U )
#define SYSTEM_MSTPCRA_MSTPA6_BIT	( 1UL << 6U )
#define SYSTEM_MSTPCRA_MSTPA7_BIT	( 1UL << 7U )
#define SYSTEM_MSTPCRA_MSTPA8_BIT	( 1UL << 8U )
#define SYSTEM_MSTPCRA_MSTPA9_BIT	( 1UL << 9U )
#define SYSTEM_MSTPCRA_MSTPA10_BIT	( 1UL << 10U )
#define SYSTEM_MSTPCRA_MSTPA11_BIT	( 1UL << 11U )
#define SYSTEM_MSTPCRA_MSTPA12_BIT	( 1UL << 12U )
#define SYSTEM_MSTPCRA_MSTPA13_BIT	( 1UL << 13U )
#define SYSTEM_MSTPCRA_MSTPA14_BIT	( 1UL << 14U )
#define SYSTEM_MSTPCRA_MSTPA15_BIT	( 1UL << 15U )
#define SYSTEM_MSTPCRA_MSTPA16_BIT	( 1UL << 16U )
#define SYSTEM_MSTPCRA_MSTPA17_BIT	( 1UL << 17U )
#define SYSTEM_MSTPCRA_MSTPA18_BIT	( 1UL << 18U )
#define SYSTEM_MSTPCRA_MSTPA19_BIT	( 1UL << 19U )
#define SYSTEM_MSTPCRA_MSTPA20_BIT	( 1UL << 20U )
#define SYSTEM_MSTPCRA_MSTPA21_BIT	( 1UL << 21U )
#define SYSTEM_MSTPCRA_MSTPA22_BIT	( 1UL << 22U )
#define SYSTEM_MSTPCRA_MSTPA23_BIT	( 1UL << 23U )
#define SYSTEM_MSTPCRA_MSTPA24_BIT	( 1UL << 24U )
#define SYSTEM_MSTPCRA_MSTPA25_BIT	( 1UL << 25U )
#define SYSTEM_MSTPCRA_MSTPA26_BIT	( 1UL << 26U )
#define SYSTEM_MSTPCRA_MSTPA27_BIT	( 1UL << 27U )
#define SYSTEM_MSTPCRA_MSTPA28_BIT	( 1UL << 28U )
#define SYSTEM_MSTPCRA_MSTPA29_BIT	( 1UL << 29U )
#define SYSTEM_MSTPCRA_MSTPA30_BIT	( 1UL << 30U )
#define SYSTEM_MSTPCRA_MSTPA31_BIT	( 1UL << 31U )
#define SYSTEM_MSTPCRA_ACSE_BIT		( 1UL << 31U)

/*
 * モジュールストップコントロールレジスタB（MSTPCRB）
 */
#define SYSTEM_MSTPCRB_ADDR			( ( volatile uint32_t __evenaccess * )0x00080014 )
#define SYSTEM_MSTPCRB_MSTPB0_BIT	( 1UL << 0U )
#define SYSTEM_MSTPCRB_MSTPB1_BIT	( 1UL << 1U )
#define SYSTEM_MSTPCRB_MSTPB2_BIT	( 1UL << 2U )
#define SYSTEM_MSTPCRB_MSTPB3_BIT	( 1UL << 3U )
#define SYSTEM_MSTPCRB_MSTPB4_BIT	( 1UL << 4U )
#define SYSTEM_MSTPCRB_MSTPB5_BIT	( 1UL << 5U )
#define SYSTEM_MSTPCRB_MSTPB6_BIT	( 1UL << 6U )
#define SYSTEM_MSTPCRB_MSTPB7_BIT	( 1UL << 7U )
#define SYSTEM_MSTPCRB_MSTPB8_BIT	( 1UL << 8U )
#define SYSTEM_MSTPCRB_MSTPB9_BIT	( 1UL << 9U )
#define SYSTEM_MSTPCRB_MSTPB10_BIT	( 1UL << 10U )
#define SYSTEM_MSTPCRB_MSTPB11_BIT	( 1UL << 11U )
#define SYSTEM_MSTPCRB_MSTPB12_BIT	( 1UL << 12U )
#define SYSTEM_MSTPCRB_MSTPB13_BIT	( 1UL << 13U )
#define SYSTEM_MSTPCRB_MSTPB14_BIT	( 1UL << 14U )
#define SYSTEM_MSTPCRB_MSTPB15_BIT	( 1UL << 15U )
#define SYSTEM_MSTPCRB_MSTPB16_BIT	( 1UL << 16U )
#define SYSTEM_MSTPCRB_MSTPB17_BIT	( 1UL << 17U )
#define SYSTEM_MSTPCRB_MSTPB18_BIT	( 1UL << 18U )
#define SYSTEM_MSTPCRB_MSTPB19_BIT	( 1UL << 19U )
#define SYSTEM_MSTPCRB_MSTPB20_BIT	( 1UL << 20U )
#define SYSTEM_MSTPCRB_MSTPB21_BIT	( 1UL << 21U )
#define SYSTEM_MSTPCRB_MSTPB22_BIT	( 1UL << 22U )
#define SYSTEM_MSTPCRB_MSTPB23_BIT	( 1UL << 23U )
#define SYSTEM_MSTPCRB_MSTPB24_BIT	( 1UL << 24U )
#define SYSTEM_MSTPCRB_MSTPB25_BIT	( 1UL << 25U )
#define SYSTEM_MSTPCRB_MSTPB26_BIT	( 1UL << 26U )
#define SYSTEM_MSTPCRB_MSTPB27_BIT	( 1UL << 27U )
#define SYSTEM_MSTPCRB_MSTPB28_BIT	( 1UL << 28U )
#define SYSTEM_MSTPCRB_MSTPB29_BIT	( 1UL << 29U )
#define SYSTEM_MSTPCRB_MSTPB30_BIT	( 1UL << 30U )
#define SYSTEM_MSTPCRB_MSTPB31_BIT	( 1UL << 31U )

/*
 * モジュールストップコントロールレジスタC（MSTPCRC）
 */
#define SYSTEM_MSTPCRC_ADDR			( ( volatile uint32_t __evenaccess * )0x00080018 )
#define SYSTEM_MSTPCRC_MSTPC0_BIT	( 1UL << 0U )
#define SYSTEM_MSTPCRC_MSTPC1_BIT	( 1UL << 1U )
#define SYSTEM_MSTPCRC_MSTPC2_BIT	( 1UL << 2U )
#define SYSTEM_MSTPCRC_MSTPC3_BIT	( 1UL << 3U )
#define SYSTEM_MSTPCRC_MSTPC4_BIT	( 1UL << 4U )
#define SYSTEM_MSTPCRC_MSTPC5_BIT	( 1UL << 5U )
#define SYSTEM_MSTPCRC_MSTPC6_BIT	( 1UL << 6U )
#define SYSTEM_MSTPCRC_MSTPC7_BIT	( 1UL << 7U )
#define SYSTEM_MSTPCRC_MSTPC8_BIT	( 1UL << 8U )
#define SYSTEM_MSTPCRC_MSTPC9_BIT	( 1UL << 9U )
#define SYSTEM_MSTPCRC_MSTPC10_BIT	( 1UL << 10U )
#define SYSTEM_MSTPCRC_MSTPC11_BIT	( 1UL << 11U )
#define SYSTEM_MSTPCRC_MSTPC12_BIT	( 1UL << 12U )
#define SYSTEM_MSTPCRC_MSTPC13_BIT	( 1UL << 13U )
#define SYSTEM_MSTPCRC_MSTPC14_BIT	( 1UL << 14U )
#define SYSTEM_MSTPCRC_MSTPC15_BIT	( 1UL << 15U )
#define SYSTEM_MSTPCRC_MSTPC16_BIT	( 1UL << 16U )
#define SYSTEM_MSTPCRC_MSTPC17_BIT	( 1UL << 17U )
#define SYSTEM_MSTPCRC_MSTPC18_BIT	( 1UL << 18U )
#define SYSTEM_MSTPCRC_MSTPC19_BIT	( 1UL << 19U )
#define SYSTEM_MSTPCRC_MSTPC20_BIT	( 1UL << 20U )
#define SYSTEM_MSTPCRC_MSTPC21_BIT	( 1UL << 21U )
#define SYSTEM_MSTPCRC_MSTPC22_BIT	( 1UL << 22U )
#define SYSTEM_MSTPCRC_MSTPC23_BIT	( 1UL << 23U )
#define SYSTEM_MSTPCRC_MSTPC24_BIT	( 1UL << 24U )
#define SYSTEM_MSTPCRC_MSTPC25_BIT	( 1UL << 25U )
#define SYSTEM_MSTPCRC_MSTPC26_BIT	( 1UL << 26U )
#define SYSTEM_MSTPCRC_MSTPC27_BIT	( 1UL << 27U )
#define SYSTEM_MSTPCRC_MSTPC28_BIT	( 1UL << 28U )
#define SYSTEM_MSTPCRC_MSTPC29_BIT	( 1UL << 29U )
#define SYSTEM_MSTPCRC_MSTPC30_BIT	( 1UL << 30U )
#define SYSTEM_MSTPCRC_MSTPC31_BIT	( 1UL << 31U )

/*
 * クロック発生回路
 */
#define SYSTEM_SCKCR_ADDR			( ( volatile uint32_t __evenaccess * )0x00080020 )
#define SYSTEM_SCKCR2_ADDR		( ( volatile uint16_t __evenaccess * )0x00080024 )
#define SYSTEM_SCKCR2_UCK_OFFSET	( 4U )
#define SYSTEM_SCKCR2_UCK_MASK		( 0xFU << SYSTEM_SCKCR2_UCK_OFFSET )
#define SYSTEM_SCKCR3_ADDR		( ( volatile uint16_t __evenaccess * )0x00080026 )
#define SYSTEM_SCKCR3_CKSEL_OFFSET	( 8U )
#define SYSTEM_SCKCR3_CKSEL_MASK	( 0x7U << SYSTEM_SCKCR3_CKSEL_OFFSET )
#define SYSTEM_PLLCR_ADDR		( ( volatile uint16_t __evenaccess * )0x00080028 )
#define SYSTEM_PLLCR_STC_OFFSET		( 8U )
#define SYSTEM_PLLCR_STC_MASK		( 0x3FU << SYSTEM_PLLCR_STC_OFFSET )
#define SYSTEM_PLLCR2_ADDR			( ( volatile uint8_t __evenaccess * )0x0008002A )
#define SYSTEM_PLLCR2_PLLEN			( 1UL << 0U )
#define SYSTEM_MOFCR_ADDR		( ( volatile uint8_t __evenaccess * )0x0008C293 )
#define SYSTEM_MOFCR_MOFXIN		( 1UL << 0U )
#define SYSTEM_MOSCCR_ADDR			( ( volatile uint8_t __evenaccess * )0x00080032 )
#define SYSTEM_MOSCCR_MOSTP			( 1UL << 0U )

/*
 * プロテクトレジスタ
 */
#define SYSTEM_PRCR_ADDR		( ( volatile uint16_t __evenaccess * )0x000803FE )

/*
 * 割り込み要求レジスタ
 */
#define ICU_IR000_ADDR			( ( volatile uint8_t __evenaccess * )0x00087000 )
#define ICU_IR001_ADDR			( ( volatile uint8_t __evenaccess * )0x00087001 )
#define ICU_IR002_ADDR			( ( volatile uint8_t __evenaccess * )0x00087002 )
#define ICU_IR003_ADDR			( ( volatile uint8_t __evenaccess * )0x00087003 )
#define ICU_IR004_ADDR			( ( volatile uint8_t __evenaccess * )0x00087004 )
#define ICU_IR005_ADDR			( ( volatile uint8_t __evenaccess * )0x00087005 )
#define ICU_IR006_ADDR			( ( volatile uint8_t __evenaccess * )0x00087006 )
#define ICU_IR007_ADDR			( ( volatile uint8_t __evenaccess * )0x00087007 )
#define ICU_IR008_ADDR			( ( volatile uint8_t __evenaccess * )0x00087008 )
#define ICU_IR009_ADDR			( ( volatile uint8_t __evenaccess * )0x00087009 )
#define ICU_IR010_ADDR			( ( volatile uint8_t __evenaccess * )0x0008700A )
#define ICU_IR011_ADDR			( ( volatile uint8_t __evenaccess * )0x0008700B )
#define ICU_IR012_ADDR			( ( volatile uint8_t __evenaccess * )0x0008700C )
#define ICU_IR013_ADDR			( ( volatile uint8_t __evenaccess * )0x0008700D )
#define ICU_IR014_ADDR			( ( volatile uint8_t __evenaccess * )0x0008700E )
#define ICU_IR015_ADDR			( ( volatile uint8_t __evenaccess * )0x0008700F )
#define ICU_IR016_ADDR			( ( volatile uint8_t __evenaccess * )0x00087010 )
#define ICU_IR017_ADDR			( ( volatile uint8_t __evenaccess * )0x00087011 )
#define ICU_IR018_ADDR			( ( volatile uint8_t __evenaccess * )0x00087012 )
#define ICU_IR019_ADDR			( ( volatile uint8_t __evenaccess * )0x00087013 )
#define ICU_IR020_ADDR			( ( volatile uint8_t __evenaccess * )0x00087014 )
#define ICU_IR021_ADDR			( ( volatile uint8_t __evenaccess * )0x00087015 )
#define ICU_IR022_ADDR			( ( volatile uint8_t __evenaccess * )0x00087016 )
#define ICU_IR023_ADDR			( ( volatile uint8_t __evenaccess * )0x00087017 )
#define ICU_IR024_ADDR			( ( volatile uint8_t __evenaccess * )0x00087018 )
#define ICU_IR025_ADDR			( ( volatile uint8_t __evenaccess * )0x00087019 )
#define ICU_IR026_ADDR			( ( volatile uint8_t __evenaccess * )0x0008701A )
#define ICU_IR027_ADDR			( ( volatile uint8_t __evenaccess * )0x0008701B )
#define ICU_IR028_ADDR			( ( volatile uint8_t __evenaccess * )0x0008701C )
#define ICU_IR029_ADDR			( ( volatile uint8_t __evenaccess * )0x0008701D )
#define ICU_IR030_ADDR			( ( volatile uint8_t __evenaccess * )0x0008701E )
#define ICU_IR031_ADDR			( ( volatile uint8_t __evenaccess * )0x0008701F )
#define ICU_IR032_ADDR			( ( volatile uint8_t __evenaccess * )0x00087020 )
#define ICU_IR033_ADDR			( ( volatile uint8_t __evenaccess * )0x00087021 )
#define ICU_IR034_ADDR			( ( volatile uint8_t __evenaccess * )0x00087022 )
#define ICU_IR035_ADDR			( ( volatile uint8_t __evenaccess * )0x00087023 )
#define ICU_IR036_ADDR			( ( volatile uint8_t __evenaccess * )0x00087024 )
#define ICU_IR037_ADDR			( ( volatile uint8_t __evenaccess * )0x00087025 )
#define ICU_IR038_ADDR			( ( volatile uint8_t __evenaccess * )0x00087026 )
#define ICU_IR039_ADDR			( ( volatile uint8_t __evenaccess * )0x00087027 )
#define ICU_IR040_ADDR			( ( volatile uint8_t __evenaccess * )0x00087028 )
#define ICU_IR041_ADDR			( ( volatile uint8_t __evenaccess * )0x00087029 )
#define ICU_IR042_ADDR			( ( volatile uint8_t __evenaccess * )0x0008702A )
#define ICU_IR043_ADDR			( ( volatile uint8_t __evenaccess * )0x0008702B )
#define ICU_IR044_ADDR			( ( volatile uint8_t __evenaccess * )0x0008702C )
#define ICU_IR045_ADDR			( ( volatile uint8_t __evenaccess * )0x0008702D )
#define ICU_IR046_ADDR			( ( volatile uint8_t __evenaccess * )0x0008702E )
#define ICU_IR047_ADDR			( ( volatile uint8_t __evenaccess * )0x0008702F )
#define ICU_IR048_ADDR			( ( volatile uint8_t __evenaccess * )0x00087030 )
#define ICU_IR049_ADDR			( ( volatile uint8_t __evenaccess * )0x00087031 )
#define ICU_IR050_ADDR			( ( volatile uint8_t __evenaccess * )0x00087032 )
#define ICU_IR051_ADDR			( ( volatile uint8_t __evenaccess * )0x00087033 )
#define ICU_IR052_ADDR			( ( volatile uint8_t __evenaccess * )0x00087034 )
#define ICU_IR053_ADDR			( ( volatile uint8_t __evenaccess * )0x00087035 )
#define ICU_IR054_ADDR			( ( volatile uint8_t __evenaccess * )0x00087036 )
#define ICU_IR055_ADDR			( ( volatile uint8_t __evenaccess * )0x00087037 )
#define ICU_IR056_ADDR			( ( volatile uint8_t __evenaccess * )0x00087038 )
#define ICU_IR057_ADDR			( ( volatile uint8_t __evenaccess * )0x00087039 )
#define ICU_IR058_ADDR			( ( volatile uint8_t __evenaccess * )0x0008703A )
#define ICU_IR059_ADDR			( ( volatile uint8_t __evenaccess * )0x0008703B )
#define ICU_IR060_ADDR			( ( volatile uint8_t __evenaccess * )0x0008703C )
#define ICU_IR061_ADDR			( ( volatile uint8_t __evenaccess * )0x0008703D )
#define ICU_IR062_ADDR			( ( volatile uint8_t __evenaccess * )0x0008703E )
#define ICU_IR063_ADDR			( ( volatile uint8_t __evenaccess * )0x0008703F )
#define ICU_IR064_ADDR			( ( volatile uint8_t __evenaccess * )0x00087040 )
#define ICU_IR065_ADDR			( ( volatile uint8_t __evenaccess * )0x00087041 )
#define ICU_IR066_ADDR			( ( volatile uint8_t __evenaccess * )0x00087042 )
#define ICU_IR067_ADDR			( ( volatile uint8_t __evenaccess * )0x00087043 )
#define ICU_IR068_ADDR			( ( volatile uint8_t __evenaccess * )0x00087044 )
#define ICU_IR069_ADDR			( ( volatile uint8_t __evenaccess * )0x00087045 )
#define ICU_IR070_ADDR			( ( volatile uint8_t __evenaccess * )0x00087046 )
#define ICU_IR071_ADDR			( ( volatile uint8_t __evenaccess * )0x00087047 )
#define ICU_IR072_ADDR			( ( volatile uint8_t __evenaccess * )0x00087048 )
#define ICU_IR073_ADDR			( ( volatile uint8_t __evenaccess * )0x00087049 )
#define ICU_IR074_ADDR			( ( volatile uint8_t __evenaccess * )0x0008704A )
#define ICU_IR075_ADDR			( ( volatile uint8_t __evenaccess * )0x0008704B )
#define ICU_IR076_ADDR			( ( volatile uint8_t __evenaccess * )0x0008704C )
#define ICU_IR077_ADDR			( ( volatile uint8_t __evenaccess * )0x0008704D )
#define ICU_IR078_ADDR			( ( volatile uint8_t __evenaccess * )0x0008704E )
#define ICU_IR079_ADDR			( ( volatile uint8_t __evenaccess * )0x0008704F )
#define ICU_IR080_ADDR			( ( volatile uint8_t __evenaccess * )0x00087050 )
#define ICU_IR081_ADDR			( ( volatile uint8_t __evenaccess * )0x00087051 )
#define ICU_IR082_ADDR			( ( volatile uint8_t __evenaccess * )0x00087052 )
#define ICU_IR083_ADDR			( ( volatile uint8_t __evenaccess * )0x00087053 )
#define ICU_IR084_ADDR			( ( volatile uint8_t __evenaccess * )0x00087054 )
#define ICU_IR085_ADDR			( ( volatile uint8_t __evenaccess * )0x00087055 )
#define ICU_IR086_ADDR			( ( volatile uint8_t __evenaccess * )0x00087056 )
#define ICU_IR087_ADDR			( ( volatile uint8_t __evenaccess * )0x00087057 )
#define ICU_IR088_ADDR			( ( volatile uint8_t __evenaccess * )0x00087058 )
#define ICU_IR089_ADDR			( ( volatile uint8_t __evenaccess * )0x00087059 )
#define ICU_IR090_ADDR			( ( volatile uint8_t __evenaccess * )0x0008705A )
#define ICU_IR091_ADDR			( ( volatile uint8_t __evenaccess * )0x0008705B )
#define ICU_IR092_ADDR			( ( volatile uint8_t __evenaccess * )0x0008705C )
#define ICU_IR093_ADDR			( ( volatile uint8_t __evenaccess * )0x0008705D )
#define ICU_IR094_ADDR			( ( volatile uint8_t __evenaccess * )0x0008705E )
#define ICU_IR095_ADDR			( ( volatile uint8_t __evenaccess * )0x0008705F )
#define ICU_IR096_ADDR			( ( volatile uint8_t __evenaccess * )0x00087060 )
#define ICU_IR097_ADDR			( ( volatile uint8_t __evenaccess * )0x00087061 )
#define ICU_IR098_ADDR			( ( volatile uint8_t __evenaccess * )0x00087062 )
#define ICU_IR099_ADDR			( ( volatile uint8_t __evenaccess * )0x00087063 )
#define ICU_IR100_ADDR			( ( volatile uint8_t __evenaccess * )0x00087064 )
#define ICU_IR101_ADDR			( ( volatile uint8_t __evenaccess * )0x00087065 )
#define ICU_IR102_ADDR			( ( volatile uint8_t __evenaccess * )0x00087066 )
#define ICU_IR103_ADDR			( ( volatile uint8_t __evenaccess * )0x00087067 )
#define ICU_IR104_ADDR			( ( volatile uint8_t __evenaccess * )0x00087068 )
#define ICU_IR105_ADDR			( ( volatile uint8_t __evenaccess * )0x00087069 )
#define ICU_IR106_ADDR			( ( volatile uint8_t __evenaccess * )0x0008706A )
#define ICU_IR107_ADDR			( ( volatile uint8_t __evenaccess * )0x0008706B )
#define ICU_IR108_ADDR			( ( volatile uint8_t __evenaccess * )0x0008706C )
#define ICU_IR109_ADDR			( ( volatile uint8_t __evenaccess * )0x0008706D )
#define ICU_IR110_ADDR			( ( volatile uint8_t __evenaccess * )0x0008706E )
#define ICU_IR111_ADDR			( ( volatile uint8_t __evenaccess * )0x0008706F )
#define ICU_IR112_ADDR			( ( volatile uint8_t __evenaccess * )0x00087070 )
#define ICU_IR113_ADDR			( ( volatile uint8_t __evenaccess * )0x00087071 )
#define ICU_IR114_ADDR			( ( volatile uint8_t __evenaccess * )0x00087072 )
#define ICU_IR115_ADDR			( ( volatile uint8_t __evenaccess * )0x00087073 )
#define ICU_IR116_ADDR			( ( volatile uint8_t __evenaccess * )0x00087074 )
#define ICU_IR117_ADDR			( ( volatile uint8_t __evenaccess * )0x00087075 )
#define ICU_IR118_ADDR			( ( volatile uint8_t __evenaccess * )0x00087076 )
#define ICU_IR119_ADDR			( ( volatile uint8_t __evenaccess * )0x00087077 )
#define ICU_IR120_ADDR			( ( volatile uint8_t __evenaccess * )0x00087078 )
#define ICU_IR121_ADDR			( ( volatile uint8_t __evenaccess * )0x00087079 )
#define ICU_IR122_ADDR			( ( volatile uint8_t __evenaccess * )0x0008707A )
#define ICU_IR123_ADDR			( ( volatile uint8_t __evenaccess * )0x0008707B )
#define ICU_IR124_ADDR			( ( volatile uint8_t __evenaccess * )0x0008707C )
#define ICU_IR125_ADDR			( ( volatile uint8_t __evenaccess * )0x0008707D )
#define ICU_IR126_ADDR			( ( volatile uint8_t __evenaccess * )0x0008707E )
#define ICU_IR127_ADDR			( ( volatile uint8_t __evenaccess * )0x0008707F )
#define ICU_IR128_ADDR			( ( volatile uint8_t __evenaccess * )0x00087080 )
#define ICU_IR129_ADDR			( ( volatile uint8_t __evenaccess * )0x00087081 )
#define ICU_IR130_ADDR			( ( volatile uint8_t __evenaccess * )0x00087082 )
#define ICU_IR131_ADDR			( ( volatile uint8_t __evenaccess * )0x00087083 )
#define ICU_IR132_ADDR			( ( volatile uint8_t __evenaccess * )0x00087084 )
#define ICU_IR133_ADDR			( ( volatile uint8_t __evenaccess * )0x00087085 )
#define ICU_IR134_ADDR			( ( volatile uint8_t __evenaccess * )0x00087086 )
#define ICU_IR135_ADDR			( ( volatile uint8_t __evenaccess * )0x00087087 )
#define ICU_IR136_ADDR			( ( volatile uint8_t __evenaccess * )0x00087088 )
#define ICU_IR137_ADDR			( ( volatile uint8_t __evenaccess * )0x00087089 )
#define ICU_IR138_ADDR			( ( volatile uint8_t __evenaccess * )0x0008708A )
#define ICU_IR139_ADDR			( ( volatile uint8_t __evenaccess * )0x0008708B )
#define ICU_IR140_ADDR			( ( volatile uint8_t __evenaccess * )0x0008708C )
#define ICU_IR141_ADDR			( ( volatile uint8_t __evenaccess * )0x0008708D )
#define ICU_IR142_ADDR			( ( volatile uint8_t __evenaccess * )0x0008708E )
#define ICU_IR143_ADDR			( ( volatile uint8_t __evenaccess * )0x0008708F )
#define ICU_IR144_ADDR			( ( volatile uint8_t __evenaccess * )0x00087090 )
#define ICU_IR145_ADDR			( ( volatile uint8_t __evenaccess * )0x00087091 )
#define ICU_IR146_ADDR			( ( volatile uint8_t __evenaccess * )0x00087092 )
#define ICU_IR147_ADDR			( ( volatile uint8_t __evenaccess * )0x00087093 )
#define ICU_IR148_ADDR			( ( volatile uint8_t __evenaccess * )0x00087094 )
#define ICU_IR149_ADDR			( ( volatile uint8_t __evenaccess * )0x00087095 )
#define ICU_IR150_ADDR			( ( volatile uint8_t __evenaccess * )0x00087096 )
#define ICU_IR151_ADDR			( ( volatile uint8_t __evenaccess * )0x00087097 )
#define ICU_IR152_ADDR			( ( volatile uint8_t __evenaccess * )0x00087098 )
#define ICU_IR153_ADDR			( ( volatile uint8_t __evenaccess * )0x00087099 )
#define ICU_IR154_ADDR			( ( volatile uint8_t __evenaccess * )0x0008709A )
#define ICU_IR155_ADDR			( ( volatile uint8_t __evenaccess * )0x0008709B )
#define ICU_IR156_ADDR			( ( volatile uint8_t __evenaccess * )0x0008709C )
#define ICU_IR157_ADDR			( ( volatile uint8_t __evenaccess * )0x0008709D )
#define ICU_IR158_ADDR			( ( volatile uint8_t __evenaccess * )0x0008709E )
#define ICU_IR159_ADDR			( ( volatile uint8_t __evenaccess * )0x0008709F )
#define ICU_IR160_ADDR			( ( volatile uint8_t __evenaccess * )0x000870A0 )
#define ICU_IR161_ADDR			( ( volatile uint8_t __evenaccess * )0x000870A1 )
#define ICU_IR162_ADDR			( ( volatile uint8_t __evenaccess * )0x000870A2 )
#define ICU_IR163_ADDR			( ( volatile uint8_t __evenaccess * )0x000870A3 )
#define ICU_IR164_ADDR			( ( volatile uint8_t __evenaccess * )0x000870A4 )
#define ICU_IR165_ADDR			( ( volatile uint8_t __evenaccess * )0x000870A5 )
#define ICU_IR166_ADDR			( ( volatile uint8_t __evenaccess * )0x000870A6 )
#define ICU_IR167_ADDR			( ( volatile uint8_t __evenaccess * )0x000870A7 )
#define ICU_IR168_ADDR			( ( volatile uint8_t __evenaccess * )0x000870A8 )
#define ICU_IR169_ADDR			( ( volatile uint8_t __evenaccess * )0x000870A9 )
#define ICU_IR170_ADDR			( ( volatile uint8_t __evenaccess * )0x000870AA )
#define ICU_IR171_ADDR			( ( volatile uint8_t __evenaccess * )0x000870AB )
#define ICU_IR172_ADDR			( ( volatile uint8_t __evenaccess * )0x000870AC )
#define ICU_IR173_ADDR			( ( volatile uint8_t __evenaccess * )0x000870AD )
#define ICU_IR174_ADDR			( ( volatile uint8_t __evenaccess * )0x000870AE )
#define ICU_IR175_ADDR			( ( volatile uint8_t __evenaccess * )0x000870AF )
#define ICU_IR176_ADDR			( ( volatile uint8_t __evenaccess * )0x000870B0 )
#define ICU_IR177_ADDR			( ( volatile uint8_t __evenaccess * )0x000870B1 )
#define ICU_IR178_ADDR			( ( volatile uint8_t __evenaccess * )0x000870B2 )
#define ICU_IR179_ADDR			( ( volatile uint8_t __evenaccess * )0x000870B3 )
#define ICU_IR180_ADDR			( ( volatile uint8_t __evenaccess * )0x000870B4 )
#define ICU_IR181_ADDR			( ( volatile uint8_t __evenaccess * )0x000870B5 )
#define ICU_IR182_ADDR			( ( volatile uint8_t __evenaccess * )0x000870B6 )
#define ICU_IR183_ADDR			( ( volatile uint8_t __evenaccess * )0x000870B7 )
#define ICU_IR184_ADDR			( ( volatile uint8_t __evenaccess * )0x000870B8 )
#define ICU_IR185_ADDR			( ( volatile uint8_t __evenaccess * )0x000870B9 )
#define ICU_IR186_ADDR			( ( volatile uint8_t __evenaccess * )0x000870BA )
#define ICU_IR187_ADDR			( ( volatile uint8_t __evenaccess * )0x000870BB )
#define ICU_IR188_ADDR			( ( volatile uint8_t __evenaccess * )0x000870BC )
#define ICU_IR189_ADDR			( ( volatile uint8_t __evenaccess * )0x000870BD )
#define ICU_IR190_ADDR			( ( volatile uint8_t __evenaccess * )0x000870BE )
#define ICU_IR191_ADDR			( ( volatile uint8_t __evenaccess * )0x000870BF )
#define ICU_IR192_ADDR			( ( volatile uint8_t __evenaccess * )0x000870C0 )
#define ICU_IR193_ADDR			( ( volatile uint8_t __evenaccess * )0x000870C1 )
#define ICU_IR194_ADDR			( ( volatile uint8_t __evenaccess * )0x000870C2 )
#define ICU_IR195_ADDR			( ( volatile uint8_t __evenaccess * )0x000870C3 )
#define ICU_IR196_ADDR			( ( volatile uint8_t __evenaccess * )0x000870C4 )
#define ICU_IR197_ADDR			( ( volatile uint8_t __evenaccess * )0x000870C5 )
#define ICU_IR198_ADDR			( ( volatile uint8_t __evenaccess * )0x000870C6 )
#define ICU_IR199_ADDR			( ( volatile uint8_t __evenaccess * )0x000870C7 )
#define ICU_IR200_ADDR			( ( volatile uint8_t __evenaccess * )0x000870C8 )
#define ICU_IR201_ADDR			( ( volatile uint8_t __evenaccess * )0x000870C9 )
#define ICU_IR202_ADDR			( ( volatile uint8_t __evenaccess * )0x000870CA )
#define ICU_IR203_ADDR			( ( volatile uint8_t __evenaccess * )0x000870CB )
#define ICU_IR204_ADDR			( ( volatile uint8_t __evenaccess * )0x000870CC )
#define ICU_IR205_ADDR			( ( volatile uint8_t __evenaccess * )0x000870CD )
#define ICU_IR206_ADDR			( ( volatile uint8_t __evenaccess * )0x000870CE )
#define ICU_IR207_ADDR			( ( volatile uint8_t __evenaccess * )0x000870CF )
#define ICU_IR208_ADDR			( ( volatile uint8_t __evenaccess * )0x000870D0 )
#define ICU_IR209_ADDR			( ( volatile uint8_t __evenaccess * )0x000870D1 )
#define ICU_IR210_ADDR			( ( volatile uint8_t __evenaccess * )0x000870D2 )
#define ICU_IR211_ADDR			( ( volatile uint8_t __evenaccess * )0x000870D3 )
#define ICU_IR212_ADDR			( ( volatile uint8_t __evenaccess * )0x000870D4 )
#define ICU_IR213_ADDR			( ( volatile uint8_t __evenaccess * )0x000870D5 )
#define ICU_IR214_ADDR			( ( volatile uint8_t __evenaccess * )0x000870D6 )
#define ICU_IR215_ADDR			( ( volatile uint8_t __evenaccess * )0x000870D7 )
#define ICU_IR216_ADDR			( ( volatile uint8_t __evenaccess * )0x000870D8 )
#define ICU_IR217_ADDR			( ( volatile uint8_t __evenaccess * )0x000870D9 )
#define ICU_IR218_ADDR			( ( volatile uint8_t __evenaccess * )0x000870DA )
#define ICU_IR219_ADDR			( ( volatile uint8_t __evenaccess * )0x000870DB )
#define ICU_IR220_ADDR			( ( volatile uint8_t __evenaccess * )0x000870DC )
#define ICU_IR221_ADDR			( ( volatile uint8_t __evenaccess * )0x000870DD )
#define ICU_IR222_ADDR			( ( volatile uint8_t __evenaccess * )0x000870DE )
#define ICU_IR223_ADDR			( ( volatile uint8_t __evenaccess * )0x000870DF )
#define ICU_IR224_ADDR			( ( volatile uint8_t __evenaccess * )0x000870E0 )
#define ICU_IR225_ADDR			( ( volatile uint8_t __evenaccess * )0x000870E1 )
#define ICU_IR226_ADDR			( ( volatile uint8_t __evenaccess * )0x000870E2 )
#define ICU_IR227_ADDR			( ( volatile uint8_t __evenaccess * )0x000870E3 )
#define ICU_IR228_ADDR			( ( volatile uint8_t __evenaccess * )0x000870E4 )
#define ICU_IR229_ADDR			( ( volatile uint8_t __evenaccess * )0x000870E5 )
#define ICU_IR230_ADDR			( ( volatile uint8_t __evenaccess * )0x000870E6 )
#define ICU_IR231_ADDR			( ( volatile uint8_t __evenaccess * )0x000870E7 )
#define ICU_IR232_ADDR			( ( volatile uint8_t __evenaccess * )0x000870E8 )
#define ICU_IR233_ADDR			( ( volatile uint8_t __evenaccess * )0x000870E9 )
#define ICU_IR234_ADDR			( ( volatile uint8_t __evenaccess * )0x000870EA )
#define ICU_IR235_ADDR			( ( volatile uint8_t __evenaccess * )0x000870EB )
#define ICU_IR236_ADDR			( ( volatile uint8_t __evenaccess * )0x000870EC )
#define ICU_IR237_ADDR			( ( volatile uint8_t __evenaccess * )0x000870ED )
#define ICU_IR238_ADDR			( ( volatile uint8_t __evenaccess * )0x000870EE )
#define ICU_IR239_ADDR			( ( volatile uint8_t __evenaccess * )0x000870EF )
#define ICU_IR240_ADDR			( ( volatile uint8_t __evenaccess * )0x000870F0 )
#define ICU_IR241_ADDR			( ( volatile uint8_t __evenaccess * )0x000870F1 )
#define ICU_IR242_ADDR			( ( volatile uint8_t __evenaccess * )0x000870F2 )
#define ICU_IR243_ADDR			( ( volatile uint8_t __evenaccess * )0x000870F3 )
#define ICU_IR244_ADDR			( ( volatile uint8_t __evenaccess * )0x000870F4 )
#define ICU_IR245_ADDR			( ( volatile uint8_t __evenaccess * )0x000870F5 )
#define ICU_IR246_ADDR			( ( volatile uint8_t __evenaccess * )0x000870F6 )
#define ICU_IR247_ADDR			( ( volatile uint8_t __evenaccess * )0x000870F7 )
#define ICU_IR248_ADDR			( ( volatile uint8_t __evenaccess * )0x000870F8 )
#define ICU_IR249_ADDR			( ( volatile uint8_t __evenaccess * )0x000870F9 )
#define ICU_IR250_ADDR			( ( volatile uint8_t __evenaccess * )0x000870FA )
#define ICU_IR251_ADDR			( ( volatile uint8_t __evenaccess * )0x000870FB )
#define ICU_IR252_ADDR			( ( volatile uint8_t __evenaccess * )0x000870FC )
#define ICU_IR253_ADDR			( ( volatile uint8_t __evenaccess * )0x000870FD )
#define ICU_IR254_ADDR			( ( volatile uint8_t __evenaccess * )0x000870FE )
#define ICU_IR255_ADDR			( ( volatile uint8_t __evenaccess * )0x000870FF )
#define ICU_IR_BIT				( 1U << 0U )

/*
 * 割り込み要求先設定レジスタ
 */
#define ICU_ISELR000_ADDR		( ( volatile uint8_t __evenaccess * )0x00087100 )
#define ICU_ISELR001_ADDR		( ( volatile uint8_t __evenaccess * )0x00087101 )
#define ICU_ISELR002_ADDR		( ( volatile uint8_t __evenaccess * )0x00087102 )
#define ICU_ISELR003_ADDR		( ( volatile uint8_t __evenaccess * )0x00087103 )
#define ICU_ISELR004_ADDR		( ( volatile uint8_t __evenaccess * )0x00087104 )
#define ICU_ISELR005_ADDR		( ( volatile uint8_t __evenaccess * )0x00087105 )
#define ICU_ISELR006_ADDR		( ( volatile uint8_t __evenaccess * )0x00087106 )
#define ICU_ISELR007_ADDR		( ( volatile uint8_t __evenaccess * )0x00087107 )
#define ICU_ISELR008_ADDR		( ( volatile uint8_t __evenaccess * )0x00087108 )
#define ICU_ISELR009_ADDR		( ( volatile uint8_t __evenaccess * )0x00087109 )
#define ICU_ISELR010_ADDR		( ( volatile uint8_t __evenaccess * )0x0008710A )
#define ICU_ISELR011_ADDR		( ( volatile uint8_t __evenaccess * )0x0008710B )
#define ICU_ISELR012_ADDR		( ( volatile uint8_t __evenaccess * )0x0008710C )
#define ICU_ISELR013_ADDR		( ( volatile uint8_t __evenaccess * )0x0008710D )
#define ICU_ISELR014_ADDR		( ( volatile uint8_t __evenaccess * )0x0008710E )
#define ICU_ISELR015_ADDR		( ( volatile uint8_t __evenaccess * )0x0008710F )
#define ICU_ISELR016_ADDR		( ( volatile uint8_t __evenaccess * )0x00087110 )
#define ICU_ISELR017_ADDR		( ( volatile uint8_t __evenaccess * )0x00087111 )
#define ICU_ISELR018_ADDR		( ( volatile uint8_t __evenaccess * )0x00087112 )
#define ICU_ISELR019_ADDR		( ( volatile uint8_t __evenaccess * )0x00087113 )
#define ICU_ISELR020_ADDR		( ( volatile uint8_t __evenaccess * )0x00087114 )
#define ICU_ISELR021_ADDR		( ( volatile uint8_t __evenaccess * )0x00087115 )
#define ICU_ISELR022_ADDR		( ( volatile uint8_t __evenaccess * )0x00087116 )
#define ICU_ISELR023_ADDR		( ( volatile uint8_t __evenaccess * )0x00087117 )
#define ICU_ISELR024_ADDR		( ( volatile uint8_t __evenaccess * )0x00087118 )
#define ICU_ISELR025_ADDR		( ( volatile uint8_t __evenaccess * )0x00087119 )
#define ICU_ISELR026_ADDR		( ( volatile uint8_t __evenaccess * )0x0008711A )
#define ICU_ISELR027_ADDR		( ( volatile uint8_t __evenaccess * )0x0008711B )
#define ICU_ISELR028_ADDR		( ( volatile uint8_t __evenaccess * )0x0008711C )
#define ICU_ISELR029_ADDR		( ( volatile uint8_t __evenaccess * )0x0008711D )
#define ICU_ISELR030_ADDR		( ( volatile uint8_t __evenaccess * )0x0008711E )
#define ICU_ISELR031_ADDR		( ( volatile uint8_t __evenaccess * )0x0008711F )
#define ICU_ISELR032_ADDR		( ( volatile uint8_t __evenaccess * )0x00087120 )
#define ICU_ISELR033_ADDR		( ( volatile uint8_t __evenaccess * )0x00087121 )
#define ICU_ISELR034_ADDR		( ( volatile uint8_t __evenaccess * )0x00087122 )
#define ICU_ISELR035_ADDR		( ( volatile uint8_t __evenaccess * )0x00087123 )
#define ICU_ISELR036_ADDR		( ( volatile uint8_t __evenaccess * )0x00087124 )
#define ICU_ISELR037_ADDR		( ( volatile uint8_t __evenaccess * )0x00087125 )
#define ICU_ISELR038_ADDR		( ( volatile uint8_t __evenaccess * )0x00087126 )
#define ICU_ISELR039_ADDR		( ( volatile uint8_t __evenaccess * )0x00087127 )
#define ICU_ISELR040_ADDR		( ( volatile uint8_t __evenaccess * )0x00087128 )
#define ICU_ISELR041_ADDR		( ( volatile uint8_t __evenaccess * )0x00087129 )
#define ICU_ISELR042_ADDR		( ( volatile uint8_t __evenaccess * )0x0008712A )
#define ICU_ISELR043_ADDR		( ( volatile uint8_t __evenaccess * )0x0008712B )
#define ICU_ISELR044_ADDR		( ( volatile uint8_t __evenaccess * )0x0008712C )
#define ICU_ISELR045_ADDR		( ( volatile uint8_t __evenaccess * )0x0008712D )
#define ICU_ISELR046_ADDR		( ( volatile uint8_t __evenaccess * )0x0008712E )
#define ICU_ISELR047_ADDR		( ( volatile uint8_t __evenaccess * )0x0008712F )
#define ICU_ISELR048_ADDR		( ( volatile uint8_t __evenaccess * )0x00087130 )
#define ICU_ISELR049_ADDR		( ( volatile uint8_t __evenaccess * )0x00087131 )
#define ICU_ISELR050_ADDR		( ( volatile uint8_t __evenaccess * )0x00087132 )
#define ICU_ISELR051_ADDR		( ( volatile uint8_t __evenaccess * )0x00087133 )
#define ICU_ISELR052_ADDR		( ( volatile uint8_t __evenaccess * )0x00087134 )
#define ICU_ISELR053_ADDR		( ( volatile uint8_t __evenaccess * )0x00087135 )
#define ICU_ISELR054_ADDR		( ( volatile uint8_t __evenaccess * )0x00087136 )
#define ICU_ISELR055_ADDR		( ( volatile uint8_t __evenaccess * )0x00087137 )
#define ICU_ISELR056_ADDR		( ( volatile uint8_t __evenaccess * )0x00087138 )
#define ICU_ISELR057_ADDR		( ( volatile uint8_t __evenaccess * )0x00087139 )
#define ICU_ISELR058_ADDR		( ( volatile uint8_t __evenaccess * )0x0008713A )
#define ICU_ISELR059_ADDR		( ( volatile uint8_t __evenaccess * )0x0008713B )
#define ICU_ISELR060_ADDR		( ( volatile uint8_t __evenaccess * )0x0008713C )
#define ICU_ISELR061_ADDR		( ( volatile uint8_t __evenaccess * )0x0008713D )
#define ICU_ISELR062_ADDR		( ( volatile uint8_t __evenaccess * )0x0008713E )
#define ICU_ISELR063_ADDR		( ( volatile uint8_t __evenaccess * )0x0008713F )
#define ICU_ISELR064_ADDR		( ( volatile uint8_t __evenaccess * )0x00087140 )
#define ICU_ISELR065_ADDR		( ( volatile uint8_t __evenaccess * )0x00087141 )
#define ICU_ISELR066_ADDR		( ( volatile uint8_t __evenaccess * )0x00087142 )
#define ICU_ISELR067_ADDR		( ( volatile uint8_t __evenaccess * )0x00087143 )
#define ICU_ISELR068_ADDR		( ( volatile uint8_t __evenaccess * )0x00087144 )
#define ICU_ISELR069_ADDR		( ( volatile uint8_t __evenaccess * )0x00087145 )
#define ICU_ISELR070_ADDR		( ( volatile uint8_t __evenaccess * )0x00087146 )
#define ICU_ISELR071_ADDR		( ( volatile uint8_t __evenaccess * )0x00087147 )
#define ICU_ISELR072_ADDR		( ( volatile uint8_t __evenaccess * )0x00087148 )
#define ICU_ISELR073_ADDR		( ( volatile uint8_t __evenaccess * )0x00087149 )
#define ICU_ISELR074_ADDR		( ( volatile uint8_t __evenaccess * )0x0008714A )
#define ICU_ISELR075_ADDR		( ( volatile uint8_t __evenaccess * )0x0008714B )
#define ICU_ISELR076_ADDR		( ( volatile uint8_t __evenaccess * )0x0008714C )
#define ICU_ISELR077_ADDR		( ( volatile uint8_t __evenaccess * )0x0008714D )
#define ICU_ISELR078_ADDR		( ( volatile uint8_t __evenaccess * )0x0008714E )
#define ICU_ISELR079_ADDR		( ( volatile uint8_t __evenaccess * )0x0008714F )
#define ICU_ISELR080_ADDR		( ( volatile uint8_t __evenaccess * )0x00087150 )
#define ICU_ISELR081_ADDR		( ( volatile uint8_t __evenaccess * )0x00087151 )
#define ICU_ISELR082_ADDR		( ( volatile uint8_t __evenaccess * )0x00087152 )
#define ICU_ISELR083_ADDR		( ( volatile uint8_t __evenaccess * )0x00087153 )
#define ICU_ISELR084_ADDR		( ( volatile uint8_t __evenaccess * )0x00087154 )
#define ICU_ISELR085_ADDR		( ( volatile uint8_t __evenaccess * )0x00087155 )
#define ICU_ISELR086_ADDR		( ( volatile uint8_t __evenaccess * )0x00087156 )
#define ICU_ISELR087_ADDR		( ( volatile uint8_t __evenaccess * )0x00087157 )
#define ICU_ISELR088_ADDR		( ( volatile uint8_t __evenaccess * )0x00087158 )
#define ICU_ISELR089_ADDR		( ( volatile uint8_t __evenaccess * )0x00087159 )
#define ICU_ISELR090_ADDR		( ( volatile uint8_t __evenaccess * )0x0008715A )
#define ICU_ISELR091_ADDR		( ( volatile uint8_t __evenaccess * )0x0008715B )
#define ICU_ISELR092_ADDR		( ( volatile uint8_t __evenaccess * )0x0008715C )
#define ICU_ISELR093_ADDR		( ( volatile uint8_t __evenaccess * )0x0008715D )
#define ICU_ISELR094_ADDR		( ( volatile uint8_t __evenaccess * )0x0008715E )
#define ICU_ISELR095_ADDR		( ( volatile uint8_t __evenaccess * )0x0008715F )
#define ICU_ISELR096_ADDR		( ( volatile uint8_t __evenaccess * )0x00087160 )
#define ICU_ISELR097_ADDR		( ( volatile uint8_t __evenaccess * )0x00087161 )
#define ICU_ISELR098_ADDR		( ( volatile uint8_t __evenaccess * )0x00087162 )
#define ICU_ISELR099_ADDR		( ( volatile uint8_t __evenaccess * )0x00087163 )
#define ICU_ISELR100_ADDR		( ( volatile uint8_t __evenaccess * )0x00087164 )
#define ICU_ISELR101_ADDR		( ( volatile uint8_t __evenaccess * )0x00087165 )
#define ICU_ISELR102_ADDR		( ( volatile uint8_t __evenaccess * )0x00087166 )
#define ICU_ISELR103_ADDR		( ( volatile uint8_t __evenaccess * )0x00087167 )
#define ICU_ISELR104_ADDR		( ( volatile uint8_t __evenaccess * )0x00087168 )
#define ICU_ISELR105_ADDR		( ( volatile uint8_t __evenaccess * )0x00087169 )
#define ICU_ISELR106_ADDR		( ( volatile uint8_t __evenaccess * )0x0008716A )
#define ICU_ISELR107_ADDR		( ( volatile uint8_t __evenaccess * )0x0008716B )
#define ICU_ISELR108_ADDR		( ( volatile uint8_t __evenaccess * )0x0008716C )
#define ICU_ISELR109_ADDR		( ( volatile uint8_t __evenaccess * )0x0008716D )
#define ICU_ISELR110_ADDR		( ( volatile uint8_t __evenaccess * )0x0008716E )
#define ICU_ISELR111_ADDR		( ( volatile uint8_t __evenaccess * )0x0008716F )
#define ICU_ISELR112_ADDR		( ( volatile uint8_t __evenaccess * )0x00087170 )
#define ICU_ISELR113_ADDR		( ( volatile uint8_t __evenaccess * )0x00087171 )
#define ICU_ISELR114_ADDR		( ( volatile uint8_t __evenaccess * )0x00087172 )
#define ICU_ISELR115_ADDR		( ( volatile uint8_t __evenaccess * )0x00087173 )
#define ICU_ISELR116_ADDR		( ( volatile uint8_t __evenaccess * )0x00087174 )
#define ICU_ISELR117_ADDR		( ( volatile uint8_t __evenaccess * )0x00087175 )
#define ICU_ISELR118_ADDR		( ( volatile uint8_t __evenaccess * )0x00087176 )
#define ICU_ISELR119_ADDR		( ( volatile uint8_t __evenaccess * )0x00087177 )
#define ICU_ISELR120_ADDR		( ( volatile uint8_t __evenaccess * )0x00087178 )
#define ICU_ISELR121_ADDR		( ( volatile uint8_t __evenaccess * )0x00087179 )
#define ICU_ISELR122_ADDR		( ( volatile uint8_t __evenaccess * )0x0008717A )
#define ICU_ISELR123_ADDR		( ( volatile uint8_t __evenaccess * )0x0008717B )
#define ICU_ISELR124_ADDR		( ( volatile uint8_t __evenaccess * )0x0008717C )
#define ICU_ISELR125_ADDR		( ( volatile uint8_t __evenaccess * )0x0008717D )
#define ICU_ISELR126_ADDR		( ( volatile uint8_t __evenaccess * )0x0008717E )
#define ICU_ISELR127_ADDR		( ( volatile uint8_t __evenaccess * )0x0008717F )
#define ICU_ISELR128_ADDR		( ( volatile uint8_t __evenaccess * )0x00087180 )
#define ICU_ISELR129_ADDR		( ( volatile uint8_t __evenaccess * )0x00087181 )
#define ICU_ISELR130_ADDR		( ( volatile uint8_t __evenaccess * )0x00087182 )
#define ICU_ISELR131_ADDR		( ( volatile uint8_t __evenaccess * )0x00087183 )
#define ICU_ISELR132_ADDR		( ( volatile uint8_t __evenaccess * )0x00087184 )
#define ICU_ISELR133_ADDR		( ( volatile uint8_t __evenaccess * )0x00087185 )
#define ICU_ISELR134_ADDR		( ( volatile uint8_t __evenaccess * )0x00087186 )
#define ICU_ISELR135_ADDR		( ( volatile uint8_t __evenaccess * )0x00087187 )
#define ICU_ISELR136_ADDR		( ( volatile uint8_t __evenaccess * )0x00087188 )
#define ICU_ISELR137_ADDR		( ( volatile uint8_t __evenaccess * )0x00087189 )
#define ICU_ISELR138_ADDR		( ( volatile uint8_t __evenaccess * )0x0008718A )
#define ICU_ISELR139_ADDR		( ( volatile uint8_t __evenaccess * )0x0008718B )
#define ICU_ISELR140_ADDR		( ( volatile uint8_t __evenaccess * )0x0008718C )
#define ICU_ISELR141_ADDR		( ( volatile uint8_t __evenaccess * )0x0008718D )
#define ICU_ISELR142_ADDR		( ( volatile uint8_t __evenaccess * )0x0008718E )
#define ICU_ISELR143_ADDR		( ( volatile uint8_t __evenaccess * )0x0008718F )
#define ICU_ISELR144_ADDR		( ( volatile uint8_t __evenaccess * )0x00087190 )
#define ICU_ISELR145_ADDR		( ( volatile uint8_t __evenaccess * )0x00087191 )
#define ICU_ISELR146_ADDR		( ( volatile uint8_t __evenaccess * )0x00087192 )
#define ICU_ISELR147_ADDR		( ( volatile uint8_t __evenaccess * )0x00087193 )
#define ICU_ISELR148_ADDR		( ( volatile uint8_t __evenaccess * )0x00087194 )
#define ICU_ISELR149_ADDR		( ( volatile uint8_t __evenaccess * )0x00087195 )
#define ICU_ISELR150_ADDR		( ( volatile uint8_t __evenaccess * )0x00087196 )
#define ICU_ISELR151_ADDR		( ( volatile uint8_t __evenaccess * )0x00087197 )
#define ICU_ISELR152_ADDR		( ( volatile uint8_t __evenaccess * )0x00087198 )
#define ICU_ISELR153_ADDR		( ( volatile uint8_t __evenaccess * )0x00087199 )
#define ICU_ISELR154_ADDR		( ( volatile uint8_t __evenaccess * )0x0008719A )
#define ICU_ISELR155_ADDR		( ( volatile uint8_t __evenaccess * )0x0008719B )
#define ICU_ISELR156_ADDR		( ( volatile uint8_t __evenaccess * )0x0008719C )
#define ICU_ISELR157_ADDR		( ( volatile uint8_t __evenaccess * )0x0008719D )
#define ICU_ISELR158_ADDR		( ( volatile uint8_t __evenaccess * )0x0008719E )
#define ICU_ISELR159_ADDR		( ( volatile uint8_t __evenaccess * )0x0008719F )
#define ICU_ISELR160_ADDR		( ( volatile uint8_t __evenaccess * )0x000871A0 )
#define ICU_ISELR161_ADDR		( ( volatile uint8_t __evenaccess * )0x000871A1 )
#define ICU_ISELR162_ADDR		( ( volatile uint8_t __evenaccess * )0x000871A2 )
#define ICU_ISELR163_ADDR		( ( volatile uint8_t __evenaccess * )0x000871A3 )
#define ICU_ISELR164_ADDR		( ( volatile uint8_t __evenaccess * )0x000871A4 )
#define ICU_ISELR165_ADDR		( ( volatile uint8_t __evenaccess * )0x000871A5 )
#define ICU_ISELR166_ADDR		( ( volatile uint8_t __evenaccess * )0x000871A6 )
#define ICU_ISELR167_ADDR		( ( volatile uint8_t __evenaccess * )0x000871A7 )
#define ICU_ISELR168_ADDR		( ( volatile uint8_t __evenaccess * )0x000871A8 )
#define ICU_ISELR169_ADDR		( ( volatile uint8_t __evenaccess * )0x000871A9 )
#define ICU_ISELR170_ADDR		( ( volatile uint8_t __evenaccess * )0x000871AA )
#define ICU_ISELR171_ADDR		( ( volatile uint8_t __evenaccess * )0x000871AB )
#define ICU_ISELR172_ADDR		( ( volatile uint8_t __evenaccess * )0x000871AC )
#define ICU_ISELR173_ADDR		( ( volatile uint8_t __evenaccess * )0x000871AD )
#define ICU_ISELR174_ADDR		( ( volatile uint8_t __evenaccess * )0x000871AE )
#define ICU_ISELR175_ADDR		( ( volatile uint8_t __evenaccess * )0x000871AF )
#define ICU_ISELR176_ADDR		( ( volatile uint8_t __evenaccess * )0x000871B0 )
#define ICU_ISELR177_ADDR		( ( volatile uint8_t __evenaccess * )0x000871B1 )
#define ICU_ISELR178_ADDR		( ( volatile uint8_t __evenaccess * )0x000871B2 )
#define ICU_ISELR179_ADDR		( ( volatile uint8_t __evenaccess * )0x000871B3 )
#define ICU_ISELR180_ADDR		( ( volatile uint8_t __evenaccess * )0x000871B4 )
#define ICU_ISELR181_ADDR		( ( volatile uint8_t __evenaccess * )0x000871B5 )
#define ICU_ISELR182_ADDR		( ( volatile uint8_t __evenaccess * )0x000871B6 )
#define ICU_ISELR183_ADDR		( ( volatile uint8_t __evenaccess * )0x000871B7 )
#define ICU_ISELR184_ADDR		( ( volatile uint8_t __evenaccess * )0x000871B8 )
#define ICU_ISELR185_ADDR		( ( volatile uint8_t __evenaccess * )0x000871B9 )
#define ICU_ISELR186_ADDR		( ( volatile uint8_t __evenaccess * )0x000871BA )
#define ICU_ISELR187_ADDR		( ( volatile uint8_t __evenaccess * )0x000871BB )
#define ICU_ISELR188_ADDR		( ( volatile uint8_t __evenaccess * )0x000871BC )
#define ICU_ISELR189_ADDR		( ( volatile uint8_t __evenaccess * )0x000871BD )
#define ICU_ISELR190_ADDR		( ( volatile uint8_t __evenaccess * )0x000871BE )
#define ICU_ISELR191_ADDR		( ( volatile uint8_t __evenaccess * )0x000871BF )
#define ICU_ISELR192_ADDR		( ( volatile uint8_t __evenaccess * )0x000871C0 )
#define ICU_ISELR193_ADDR		( ( volatile uint8_t __evenaccess * )0x000871C1 )
#define ICU_ISELR194_ADDR		( ( volatile uint8_t __evenaccess * )0x000871C2 )
#define ICU_ISELR195_ADDR		( ( volatile uint8_t __evenaccess * )0x000871C3 )
#define ICU_ISELR196_ADDR		( ( volatile uint8_t __evenaccess * )0x000871C4 )
#define ICU_ISELR197_ADDR		( ( volatile uint8_t __evenaccess * )0x000871C5 )
#define ICU_ISELR198_ADDR		( ( volatile uint8_t __evenaccess * )0x000871C6 )
#define ICU_ISELR199_ADDR		( ( volatile uint8_t __evenaccess * )0x000871C7 )
#define ICU_ISELR200_ADDR		( ( volatile uint8_t __evenaccess * )0x000871C8 )
#define ICU_ISELR201_ADDR		( ( volatile uint8_t __evenaccess * )0x000871C9 )
#define ICU_ISELR202_ADDR		( ( volatile uint8_t __evenaccess * )0x000871CA )
#define ICU_ISELR203_ADDR		( ( volatile uint8_t __evenaccess * )0x000871CB )
#define ICU_ISELR204_ADDR		( ( volatile uint8_t __evenaccess * )0x000871CC )
#define ICU_ISELR205_ADDR		( ( volatile uint8_t __evenaccess * )0x000871CD )
#define ICU_ISELR206_ADDR		( ( volatile uint8_t __evenaccess * )0x000871CE )
#define ICU_ISELR207_ADDR		( ( volatile uint8_t __evenaccess * )0x000871CF )
#define ICU_ISELR208_ADDR		( ( volatile uint8_t __evenaccess * )0x000871D0 )
#define ICU_ISELR209_ADDR		( ( volatile uint8_t __evenaccess * )0x000871D1 )
#define ICU_ISELR210_ADDR		( ( volatile uint8_t __evenaccess * )0x000871D2 )
#define ICU_ISELR211_ADDR		( ( volatile uint8_t __evenaccess * )0x000871D3 )
#define ICU_ISELR212_ADDR		( ( volatile uint8_t __evenaccess * )0x000871D4 )
#define ICU_ISELR213_ADDR		( ( volatile uint8_t __evenaccess * )0x000871D5 )
#define ICU_ISELR214_ADDR		( ( volatile uint8_t __evenaccess * )0x000871D6 )
#define ICU_ISELR215_ADDR		( ( volatile uint8_t __evenaccess * )0x000871D7 )
#define ICU_ISELR216_ADDR		( ( volatile uint8_t __evenaccess * )0x000871D8 )
#define ICU_ISELR217_ADDR		( ( volatile uint8_t __evenaccess * )0x000871D9 )
#define ICU_ISELR218_ADDR		( ( volatile uint8_t __evenaccess * )0x000871DA )
#define ICU_ISELR219_ADDR		( ( volatile uint8_t __evenaccess * )0x000871DB )
#define ICU_ISELR220_ADDR		( ( volatile uint8_t __evenaccess * )0x000871DC )
#define ICU_ISELR221_ADDR		( ( volatile uint8_t __evenaccess * )0x000871DD )
#define ICU_ISELR222_ADDR		( ( volatile uint8_t __evenaccess * )0x000871DE )
#define ICU_ISELR223_ADDR		( ( volatile uint8_t __evenaccess * )0x000871DF )
#define ICU_ISELR224_ADDR		( ( volatile uint8_t __evenaccess * )0x000871E0 )
#define ICU_ISELR225_ADDR		( ( volatile uint8_t __evenaccess * )0x000871E1 )
#define ICU_ISELR226_ADDR		( ( volatile uint8_t __evenaccess * )0x000871E2 )
#define ICU_ISELR227_ADDR		( ( volatile uint8_t __evenaccess * )0x000871E3 )
#define ICU_ISELR228_ADDR		( ( volatile uint8_t __evenaccess * )0x000871E4 )
#define ICU_ISELR229_ADDR		( ( volatile uint8_t __evenaccess * )0x000871E5 )
#define ICU_ISELR230_ADDR		( ( volatile uint8_t __evenaccess * )0x000871E6 )
#define ICU_ISELR231_ADDR		( ( volatile uint8_t __evenaccess * )0x000871E7 )
#define ICU_ISELR232_ADDR		( ( volatile uint8_t __evenaccess * )0x000871E8 )
#define ICU_ISELR233_ADDR		( ( volatile uint8_t __evenaccess * )0x000871E9 )
#define ICU_ISELR234_ADDR		( ( volatile uint8_t __evenaccess * )0x000871EA )
#define ICU_ISELR235_ADDR		( ( volatile uint8_t __evenaccess * )0x000871EB )
#define ICU_ISELR236_ADDR		( ( volatile uint8_t __evenaccess * )0x000871EC )
#define ICU_ISELR237_ADDR		( ( volatile uint8_t __evenaccess * )0x000871ED )
#define ICU_ISELR238_ADDR		( ( volatile uint8_t __evenaccess * )0x000871EE )
#define ICU_ISELR239_ADDR		( ( volatile uint8_t __evenaccess * )0x000871EF )
#define ICU_ISELR240_ADDR		( ( volatile uint8_t __evenaccess * )0x000871F0 )
#define ICU_ISELR241_ADDR		( ( volatile uint8_t __evenaccess * )0x000871F1 )
#define ICU_ISELR242_ADDR		( ( volatile uint8_t __evenaccess * )0x000871F2 )
#define ICU_ISELR243_ADDR		( ( volatile uint8_t __evenaccess * )0x000871F3 )
#define ICU_ISELR244_ADDR		( ( volatile uint8_t __evenaccess * )0x000871F4 )
#define ICU_ISELR245_ADDR		( ( volatile uint8_t __evenaccess * )0x000871F5 )
#define ICU_ISELR246_ADDR		( ( volatile uint8_t __evenaccess * )0x000871F6 )
#define ICU_ISELR247_ADDR		( ( volatile uint8_t __evenaccess * )0x000871F7 )
#define ICU_ISELR248_ADDR		( ( volatile uint8_t __evenaccess * )0x000871F8 )
#define ICU_ISELR249_ADDR		( ( volatile uint8_t __evenaccess * )0x000871F9 )
#define ICU_ISELR250_ADDR		( ( volatile uint8_t __evenaccess * )0x000871FA )
#define ICU_ISELR251_ADDR		( ( volatile uint8_t __evenaccess * )0x000871FB )
#define ICU_ISELR252_ADDR		( ( volatile uint8_t __evenaccess * )0x000871FC )
#define ICU_ISELR253_ADDR		( ( volatile uint8_t __evenaccess * )0x000871FD )
#define ICU_ISELR254_ADDR		( ( volatile uint8_t __evenaccess * )0x000871FE )
#define ICU_ISELR255_ADDR		( ( volatile uint8_t __evenaccess * )0x000871FF )
#define ICU_ISEL_BIT			( 3U << 0U )

/*
 * 割り込み要求許可レジスタ
 */
#define ICU_IER02_ADDR			( ( volatile uint8_t __evenaccess * )0x00087202 )
#define ICU_IER03_ADDR			( ( volatile uint8_t __evenaccess * )0x00087203 )
#define ICU_IER04_ADDR			( ( volatile uint8_t __evenaccess * )0x00087204 )
#define ICU_IER05_ADDR			( ( volatile uint8_t __evenaccess * )0x00087205 )
#define ICU_IER06_ADDR			( ( volatile uint8_t __evenaccess * )0x00087206 )
#define ICU_IER07_ADDR			( ( volatile uint8_t __evenaccess * )0x00087207 )
#define ICU_IER08_ADDR			( ( volatile uint8_t __evenaccess * )0x00087208 )
#define ICU_IER09_ADDR			( ( volatile uint8_t __evenaccess * )0x00087209 )
#define ICU_IER0B_ADDR			( ( volatile uint8_t __evenaccess * )0x0008720B )
#define ICU_IER0C_ADDR			( ( volatile uint8_t __evenaccess * )0x0008720C )
#define ICU_IER0D_ADDR			( ( volatile uint8_t __evenaccess * )0x0008720D )
#define ICU_IER0E_ADDR			( ( volatile uint8_t __evenaccess * )0x0008720E )
#define ICU_IER0F_ADDR			( ( volatile uint8_t __evenaccess * )0x0008720F )
#define ICU_IER10_ADDR			( ( volatile uint8_t __evenaccess * )0x00087210 )
#define ICU_IER11_ADDR			( ( volatile uint8_t __evenaccess * )0x00087211 )
#define ICU_IER12_ADDR			( ( volatile uint8_t __evenaccess * )0x00087212 )
#define ICU_IER13_ADDR			( ( volatile uint8_t __evenaccess * )0x00087213 )
#define ICU_IER14_ADDR			( ( volatile uint8_t __evenaccess * )0x00087214 )
#define ICU_IER15_ADDR			( ( volatile uint8_t __evenaccess * )0x00087215 )
#define ICU_IER16_ADDR			( ( volatile uint8_t __evenaccess * )0x00087216 )
#define ICU_IER17_ADDR			( ( volatile uint8_t __evenaccess * )0x00087217 )
#define ICU_IER18_ADDR			( ( volatile uint8_t __evenaccess * )0x00087218 )
#define ICU_IER19_ADDR			( ( volatile uint8_t __evenaccess * )0x00087219 )
#define ICU_IER1A_ADDR			( ( volatile uint8_t __evenaccess * )0x0008721A )
#define ICU_IER1B_ADDR			( ( volatile uint8_t __evenaccess * )0x0008721B )
#define ICU_IER1C_ADDR			( ( volatile uint8_t __evenaccess * )0x0008721C )
#define ICU_IER1D_ADDR			( ( volatile uint8_t __evenaccess * )0x0008721D )
#define ICU_IER1E_ADDR			( ( volatile uint8_t __evenaccess * )0x0008721E )
#define ICU_IER1F_ADDR			( ( volatile uint8_t __evenaccess * )0x0008721F )
#define ICU_IEN0_BIT			( 1U << 0U )
#define ICU_IEN1_BIT			( 1U << 1U )
#define ICU_IEN2_BIT			( 1U << 2U )
#define ICU_IEN3_BIT			( 1U << 3U )
#define ICU_IEN4_BIT			( 1U << 4U )
#define ICU_IEN5_BIT			( 1U << 5U )
#define ICU_IEN6_BIT			( 1U << 6U )
#define ICU_IEN7_BIT			( 1U << 7U )

/* 
 * 割り込み要因プライオリティレジスタi(i=0～253)の設定
 */
#define ICU_IPR000_ADDR			( ( volatile uint8_t __evenaccess * )0x00087300 )
#define ICU_IPR001_ADDR			( ( volatile uint8_t __evenaccess * )0x00087301 )
#define ICU_IPR002_ADDR			( ( volatile uint8_t __evenaccess * )0x00087302 )
#define ICU_IPR003_ADDR			( ( volatile uint8_t __evenaccess * )0x00087303 )
#define ICU_IPR004_ADDR			( ( volatile uint8_t __evenaccess * )0x00087304 )
#define ICU_IPR005_ADDR			( ( volatile uint8_t __evenaccess * )0x00087305 )
#define ICU_IPR006_ADDR			( ( volatile uint8_t __evenaccess * )0x00087306 )
#define ICU_IPR007_ADDR			( ( volatile uint8_t __evenaccess * )0x00087307 )
#define ICU_IPR008_ADDR			( ( volatile uint8_t __evenaccess * )0x00087308 )
#define ICU_IPR009_ADDR			( ( volatile uint8_t __evenaccess * )0x00087309 )
#define ICU_IPR010_ADDR			( ( volatile uint8_t __evenaccess * )0x0008730A )
#define ICU_IPR011_ADDR			( ( volatile uint8_t __evenaccess * )0x0008730B )
#define ICU_IPR012_ADDR			( ( volatile uint8_t __evenaccess * )0x0008730C )
#define ICU_IPR013_ADDR			( ( volatile uint8_t __evenaccess * )0x0008730D )
#define ICU_IPR014_ADDR			( ( volatile uint8_t __evenaccess * )0x0008730E )
#define ICU_IPR015_ADDR			( ( volatile uint8_t __evenaccess * )0x0008730F )
#define ICU_IPR016_ADDR			( ( volatile uint8_t __evenaccess * )0x00087310 )
#define ICU_IPR017_ADDR			( ( volatile uint8_t __evenaccess * )0x00087311 )
#define ICU_IPR018_ADDR			( ( volatile uint8_t __evenaccess * )0x00087312 )
#define ICU_IPR019_ADDR			( ( volatile uint8_t __evenaccess * )0x00087313 )
#define ICU_IPR020_ADDR			( ( volatile uint8_t __evenaccess * )0x00087314 )
#define ICU_IPR021_ADDR			( ( volatile uint8_t __evenaccess * )0x00087315 )
#define ICU_IPR022_ADDR			( ( volatile uint8_t __evenaccess * )0x00087316 )
#define ICU_IPR023_ADDR			( ( volatile uint8_t __evenaccess * )0x00087317 )
#define ICU_IPR024_ADDR			( ( volatile uint8_t __evenaccess * )0x00087318 )
#define ICU_IPR025_ADDR			( ( volatile uint8_t __evenaccess * )0x00087319 )
#define ICU_IPR026_ADDR			( ( volatile uint8_t __evenaccess * )0x0008731A )
#define ICU_IPR027_ADDR			( ( volatile uint8_t __evenaccess * )0x0008731B )
#define ICU_IPR028_ADDR			( ( volatile uint8_t __evenaccess * )0x0008731C )
#define ICU_IPR029_ADDR			( ( volatile uint8_t __evenaccess * )0x0008731D )
#define ICU_IPR030_ADDR			( ( volatile uint8_t __evenaccess * )0x0008731E )
#define ICU_IPR031_ADDR			( ( volatile uint8_t __evenaccess * )0x0008731F )
#define ICU_IPR032_ADDR			( ( volatile uint8_t __evenaccess * )0x00087320 )
#define ICU_IPR033_ADDR			( ( volatile uint8_t __evenaccess * )0x00087321 )
#define ICU_IPR034_ADDR			( ( volatile uint8_t __evenaccess * )0x00087322 )
#define ICU_IPR035_ADDR			( ( volatile uint8_t __evenaccess * )0x00087323 )
#define ICU_IPR036_ADDR			( ( volatile uint8_t __evenaccess * )0x00087324 )
#define ICU_IPR037_ADDR			( ( volatile uint8_t __evenaccess * )0x00087325 )
#define ICU_IPR038_ADDR			( ( volatile uint8_t __evenaccess * )0x00087326 )
#define ICU_IPR039_ADDR			( ( volatile uint8_t __evenaccess * )0x00087327 )
#define ICU_IPR040_ADDR			( ( volatile uint8_t __evenaccess * )0x00087328 )
#define ICU_IPR041_ADDR			( ( volatile uint8_t __evenaccess * )0x00087329 )
#define ICU_IPR042_ADDR			( ( volatile uint8_t __evenaccess * )0x0008732A )
#define ICU_IPR043_ADDR			( ( volatile uint8_t __evenaccess * )0x0008732B )
#define ICU_IPR044_ADDR			( ( volatile uint8_t __evenaccess * )0x0008732C )
#define ICU_IPR045_ADDR			( ( volatile uint8_t __evenaccess * )0x0008732D )
#define ICU_IPR046_ADDR			( ( volatile uint8_t __evenaccess * )0x0008732E )
#define ICU_IPR047_ADDR			( ( volatile uint8_t __evenaccess * )0x0008732F )
#define ICU_IPR048_ADDR			( ( volatile uint8_t __evenaccess * )0x00087330 )
#define ICU_IPR049_ADDR			( ( volatile uint8_t __evenaccess * )0x00087331 )
#define ICU_IPR050_ADDR			( ( volatile uint8_t __evenaccess * )0x00087332 )
#define ICU_IPR051_ADDR			( ( volatile uint8_t __evenaccess * )0x00087333 )
#define ICU_IPR052_ADDR			( ( volatile uint8_t __evenaccess * )0x00087334 )
#define ICU_IPR053_ADDR			( ( volatile uint8_t __evenaccess * )0x00087335 )
#define ICU_IPR054_ADDR			( ( volatile uint8_t __evenaccess * )0x00087336 )
#define ICU_IPR055_ADDR			( ( volatile uint8_t __evenaccess * )0x00087337 )
#define ICU_IPR056_ADDR			( ( volatile uint8_t __evenaccess * )0x00087338 )
#define ICU_IPR057_ADDR			( ( volatile uint8_t __evenaccess * )0x00087339 )
#define ICU_IPR058_ADDR			( ( volatile uint8_t __evenaccess * )0x0008733A )
#define ICU_IPR059_ADDR			( ( volatile uint8_t __evenaccess * )0x0008733B )
#define ICU_IPR060_ADDR			( ( volatile uint8_t __evenaccess * )0x0008733C )
#define ICU_IPR061_ADDR			( ( volatile uint8_t __evenaccess * )0x0008733D )
#define ICU_IPR062_ADDR			( ( volatile uint8_t __evenaccess * )0x0008733E )
#define ICU_IPR063_ADDR			( ( volatile uint8_t __evenaccess * )0x0008733F )
#define ICU_IPR064_ADDR			( ( volatile uint8_t __evenaccess * )0x00087340 )
#define ICU_IPR065_ADDR			( ( volatile uint8_t __evenaccess * )0x00087341 )
#define ICU_IPR066_ADDR			( ( volatile uint8_t __evenaccess * )0x00087342 )
#define ICU_IPR067_ADDR			( ( volatile uint8_t __evenaccess * )0x00087343 )
#define ICU_IPR068_ADDR			( ( volatile uint8_t __evenaccess * )0x00087344 )
#define ICU_IPR069_ADDR			( ( volatile uint8_t __evenaccess * )0x00087345 )
#define ICU_IPR070_ADDR			( ( volatile uint8_t __evenaccess * )0x00087346 )
#define ICU_IPR071_ADDR			( ( volatile uint8_t __evenaccess * )0x00087347 )
#define ICU_IPR072_ADDR			( ( volatile uint8_t __evenaccess * )0x00087348 )
#define ICU_IPR073_ADDR			( ( volatile uint8_t __evenaccess * )0x00087349 )
#define ICU_IPR074_ADDR			( ( volatile uint8_t __evenaccess * )0x0008734A )
#define ICU_IPR075_ADDR			( ( volatile uint8_t __evenaccess * )0x0008734B )
#define ICU_IPR076_ADDR			( ( volatile uint8_t __evenaccess * )0x0008734C )
#define ICU_IPR077_ADDR			( ( volatile uint8_t __evenaccess * )0x0008734D )
#define ICU_IPR078_ADDR			( ( volatile uint8_t __evenaccess * )0x0008734E )
#define ICU_IPR079_ADDR			( ( volatile uint8_t __evenaccess * )0x0008734F )
#define ICU_IPR080_ADDR			( ( volatile uint8_t __evenaccess * )0x00087350 )
#define ICU_IPR081_ADDR			( ( volatile uint8_t __evenaccess * )0x00087351 )
#define ICU_IPR082_ADDR			( ( volatile uint8_t __evenaccess * )0x00087352 )
#define ICU_IPR083_ADDR			( ( volatile uint8_t __evenaccess * )0x00087353 )
#define ICU_IPR084_ADDR			( ( volatile uint8_t __evenaccess * )0x00087354 )
#define ICU_IPR085_ADDR			( ( volatile uint8_t __evenaccess * )0x00087355 )
#define ICU_IPR086_ADDR			( ( volatile uint8_t __evenaccess * )0x00087356 )
#define ICU_IPR087_ADDR			( ( volatile uint8_t __evenaccess * )0x00087357 )
#define ICU_IPR088_ADDR			( ( volatile uint8_t __evenaccess * )0x00087358 )
#define ICU_IPR089_ADDR			( ( volatile uint8_t __evenaccess * )0x00087359 )
#define ICU_IPR090_ADDR			( ( volatile uint8_t __evenaccess * )0x0008735A )
#define ICU_IPR091_ADDR			( ( volatile uint8_t __evenaccess * )0x0008735B )
#define ICU_IPR092_ADDR			( ( volatile uint8_t __evenaccess * )0x0008735C )
#define ICU_IPR093_ADDR			( ( volatile uint8_t __evenaccess * )0x0008735D )
#define ICU_IPR094_ADDR			( ( volatile uint8_t __evenaccess * )0x0008735E )
#define ICU_IPR095_ADDR			( ( volatile uint8_t __evenaccess * )0x0008735F )
#define ICU_IPR096_ADDR			( ( volatile uint8_t __evenaccess * )0x00087360 )
#define ICU_IPR097_ADDR			( ( volatile uint8_t __evenaccess * )0x00087361 )
#define ICU_IPR098_ADDR			( ( volatile uint8_t __evenaccess * )0x00087362 )
#define ICU_IPR099_ADDR			( ( volatile uint8_t __evenaccess * )0x00087363 )
#define ICU_IPR100_ADDR			( ( volatile uint8_t __evenaccess * )0x00087364 )
#define ICU_IPR101_ADDR			( ( volatile uint8_t __evenaccess * )0x00087365 )
#define ICU_IPR102_ADDR			( ( volatile uint8_t __evenaccess * )0x00087366 )
#define ICU_IPR103_ADDR			( ( volatile uint8_t __evenaccess * )0x00087367 )
#define ICU_IPR104_ADDR			( ( volatile uint8_t __evenaccess * )0x00087368 )
#define ICU_IPR105_ADDR			( ( volatile uint8_t __evenaccess * )0x00087369 )
#define ICU_IPR106_ADDR			( ( volatile uint8_t __evenaccess * )0x0008736A )
#define ICU_IPR107_ADDR			( ( volatile uint8_t __evenaccess * )0x0008736B )
#define ICU_IPR108_ADDR			( ( volatile uint8_t __evenaccess * )0x0008736C )
#define ICU_IPR109_ADDR			( ( volatile uint8_t __evenaccess * )0x0008736D )
#define ICU_IPR110_ADDR			( ( volatile uint8_t __evenaccess * )0x0008736E )
#define ICU_IPR111_ADDR			( ( volatile uint8_t __evenaccess * )0x0008736F )
#define ICU_IPR112_ADDR			( ( volatile uint8_t __evenaccess * )0x00087370 )
#define ICU_IPR113_ADDR			( ( volatile uint8_t __evenaccess * )0x00087371 )
#define ICU_IPR114_ADDR			( ( volatile uint8_t __evenaccess * )0x00087372 )
#define ICU_IPR115_ADDR			( ( volatile uint8_t __evenaccess * )0x00087373 )
#define ICU_IPR116_ADDR			( ( volatile uint8_t __evenaccess * )0x00087374 )
#define ICU_IPR117_ADDR			( ( volatile uint8_t __evenaccess * )0x00087375 )
#define ICU_IPR118_ADDR			( ( volatile uint8_t __evenaccess * )0x00087376 )
#define ICU_IPR119_ADDR			( ( volatile uint8_t __evenaccess * )0x00087377 )
#define ICU_IPR120_ADDR			( ( volatile uint8_t __evenaccess * )0x00087378 )
#define ICU_IPR121_ADDR			( ( volatile uint8_t __evenaccess * )0x00087379 )
#define ICU_IPR122_ADDR			( ( volatile uint8_t __evenaccess * )0x0008737A )
#define ICU_IPR123_ADDR			( ( volatile uint8_t __evenaccess * )0x0008737B )
#define ICU_IPR124_ADDR			( ( volatile uint8_t __evenaccess * )0x0008737C )
#define ICU_IPR125_ADDR			( ( volatile uint8_t __evenaccess * )0x0008737D )
#define ICU_IPR126_ADDR			( ( volatile uint8_t __evenaccess * )0x0008737E )
#define ICU_IPR127_ADDR			( ( volatile uint8_t __evenaccess * )0x0008737F )
#define ICU_IPR128_ADDR			( ( volatile uint8_t __evenaccess * )0x00087380 )
#define ICU_IPR129_ADDR			( ( volatile uint8_t __evenaccess * )0x00087381 )
#define ICU_IPR130_ADDR			( ( volatile uint8_t __evenaccess * )0x00087382 )
#define ICU_IPR131_ADDR			( ( volatile uint8_t __evenaccess * )0x00087383 )
#define ICU_IPR132_ADDR			( ( volatile uint8_t __evenaccess * )0x00087384 )
#define ICU_IPR133_ADDR			( ( volatile uint8_t __evenaccess * )0x00087385 )
#define ICU_IPR134_ADDR			( ( volatile uint8_t __evenaccess * )0x00087386 )
#define ICU_IPR135_ADDR			( ( volatile uint8_t __evenaccess * )0x00087387 )
#define ICU_IPR136_ADDR			( ( volatile uint8_t __evenaccess * )0x00087388 )
#define ICU_IPR137_ADDR			( ( volatile uint8_t __evenaccess * )0x00087389 )
#define ICU_IPR138_ADDR			( ( volatile uint8_t __evenaccess * )0x0008738A )
#define ICU_IPR139_ADDR			( ( volatile uint8_t __evenaccess * )0x0008738B )
#define ICU_IPR140_ADDR			( ( volatile uint8_t __evenaccess * )0x0008738C )
#define ICU_IPR141_ADDR			( ( volatile uint8_t __evenaccess * )0x0008738D )
#define ICU_IPR142_ADDR			( ( volatile uint8_t __evenaccess * )0x0008738E )
#define ICU_IPR143_ADDR			( ( volatile uint8_t __evenaccess * )0x0008738F )
#define ICU_IPR144_ADDR			( ( volatile uint8_t __evenaccess * )0x00087390 )
#define ICU_IPR145_ADDR			( ( volatile uint8_t __evenaccess * )0x00087391 )
#define ICU_IPR146_ADDR			( ( volatile uint8_t __evenaccess * )0x00087392 )
#define ICU_IPR147_ADDR			( ( volatile uint8_t __evenaccess * )0x00087393 )
#define ICU_IPR148_ADDR			( ( volatile uint8_t __evenaccess * )0x00087394 )
#define ICU_IPR149_ADDR			( ( volatile uint8_t __evenaccess * )0x00087395 )
#define ICU_IPR150_ADDR			( ( volatile uint8_t __evenaccess * )0x00087396 )
#define ICU_IPR151_ADDR			( ( volatile uint8_t __evenaccess * )0x00087397 )
#define ICU_IPR152_ADDR			( ( volatile uint8_t __evenaccess * )0x00087398 )
#define ICU_IPR153_ADDR			( ( volatile uint8_t __evenaccess * )0x00087399 )
#define ICU_IPR154_ADDR			( ( volatile uint8_t __evenaccess * )0x0008739A )
#define ICU_IPR155_ADDR			( ( volatile uint8_t __evenaccess * )0x0008739B )
#define ICU_IPR156_ADDR			( ( volatile uint8_t __evenaccess * )0x0008739C )
#define ICU_IPR157_ADDR			( ( volatile uint8_t __evenaccess * )0x0008739D )
#define ICU_IPR158_ADDR			( ( volatile uint8_t __evenaccess * )0x0008739E )
#define ICU_IPR159_ADDR			( ( volatile uint8_t __evenaccess * )0x0008739F )
#define ICU_IPR160_ADDR			( ( volatile uint8_t __evenaccess * )0x000873A0 )
#define ICU_IPR161_ADDR			( ( volatile uint8_t __evenaccess * )0x000873A1 )
#define ICU_IPR162_ADDR			( ( volatile uint8_t __evenaccess * )0x000873A2 )
#define ICU_IPR163_ADDR			( ( volatile uint8_t __evenaccess * )0x000873A3 )
#define ICU_IPR164_ADDR			( ( volatile uint8_t __evenaccess * )0x000873A4 )
#define ICU_IPR165_ADDR			( ( volatile uint8_t __evenaccess * )0x000873A5 )
#define ICU_IPR166_ADDR			( ( volatile uint8_t __evenaccess * )0x000873A6 )
#define ICU_IPR167_ADDR			( ( volatile uint8_t __evenaccess * )0x000873A7 )
#define ICU_IPR168_ADDR			( ( volatile uint8_t __evenaccess * )0x000873A8 )
#define ICU_IPR169_ADDR			( ( volatile uint8_t __evenaccess * )0x000873A9 )
#define ICU_IPR170_ADDR			( ( volatile uint8_t __evenaccess * )0x000873AA )
#define ICU_IPR171_ADDR			( ( volatile uint8_t __evenaccess * )0x000873AB )
#define ICU_IPR172_ADDR			( ( volatile uint8_t __evenaccess * )0x000873AC )
#define ICU_IPR173_ADDR			( ( volatile uint8_t __evenaccess * )0x000873AD )
#define ICU_IPR174_ADDR			( ( volatile uint8_t __evenaccess * )0x000873AE )
#define ICU_IPR175_ADDR			( ( volatile uint8_t __evenaccess * )0x000873AF )
#define ICU_IPR176_ADDR			( ( volatile uint8_t __evenaccess * )0x000873B0 )
#define ICU_IPR177_ADDR			( ( volatile uint8_t __evenaccess * )0x000873B1 )
#define ICU_IPR178_ADDR			( ( volatile uint8_t __evenaccess * )0x000873B2 )
#define ICU_IPR179_ADDR			( ( volatile uint8_t __evenaccess * )0x000873B3 )
#define ICU_IPR180_ADDR			( ( volatile uint8_t __evenaccess * )0x000873B4 )
#define ICU_IPR181_ADDR			( ( volatile uint8_t __evenaccess * )0x000873B5 )
#define ICU_IPR182_ADDR			( ( volatile uint8_t __evenaccess * )0x000873B6 )
#define ICU_IPR183_ADDR			( ( volatile uint8_t __evenaccess * )0x000873B7 )
#define ICU_IPR184_ADDR			( ( volatile uint8_t __evenaccess * )0x000873B8 )
#define ICU_IPR185_ADDR			( ( volatile uint8_t __evenaccess * )0x000873B9 )
#define ICU_IPR186_ADDR			( ( volatile uint8_t __evenaccess * )0x000873BA )
#define ICU_IPR187_ADDR			( ( volatile uint8_t __evenaccess * )0x000873BB )
#define ICU_IPR188_ADDR			( ( volatile uint8_t __evenaccess * )0x000873BC )
#define ICU_IPR189_ADDR			( ( volatile uint8_t __evenaccess * )0x000873BD )
#define ICU_IPR190_ADDR			( ( volatile uint8_t __evenaccess * )0x000873BE )
#define ICU_IPR191_ADDR			( ( volatile uint8_t __evenaccess * )0x000873BF )
#define ICU_IPR192_ADDR			( ( volatile uint8_t __evenaccess * )0x000873C0 )
#define ICU_IPR193_ADDR			( ( volatile uint8_t __evenaccess * )0x000873C1 )
#define ICU_IPR194_ADDR			( ( volatile uint8_t __evenaccess * )0x000873C2 )
#define ICU_IPR195_ADDR			( ( volatile uint8_t __evenaccess * )0x000873C3 )
#define ICU_IPR196_ADDR			( ( volatile uint8_t __evenaccess * )0x000873C4 )
#define ICU_IPR197_ADDR			( ( volatile uint8_t __evenaccess * )0x000873C5 )
#define ICU_IPR198_ADDR			( ( volatile uint8_t __evenaccess * )0x000873C6 )
#define ICU_IPR199_ADDR			( ( volatile uint8_t __evenaccess * )0x000873C7 )
#define ICU_IPR200_ADDR			( ( volatile uint8_t __evenaccess * )0x000873C8 )
#define ICU_IPR201_ADDR			( ( volatile uint8_t __evenaccess * )0x000873C9 )
#define ICU_IPR202_ADDR			( ( volatile uint8_t __evenaccess * )0x000873CA )
#define ICU_IPR203_ADDR			( ( volatile uint8_t __evenaccess * )0x000873CB )
#define ICU_IPR204_ADDR			( ( volatile uint8_t __evenaccess * )0x000873CC )
#define ICU_IPR205_ADDR			( ( volatile uint8_t __evenaccess * )0x000873CD )
#define ICU_IPR206_ADDR			( ( volatile uint8_t __evenaccess * )0x000873CE )
#define ICU_IPR207_ADDR			( ( volatile uint8_t __evenaccess * )0x000873CF )
#define ICU_IPR208_ADDR			( ( volatile uint8_t __evenaccess * )0x000873D0 )
#define ICU_IPR209_ADDR			( ( volatile uint8_t __evenaccess * )0x000873D1 )
#define ICU_IPR210_ADDR			( ( volatile uint8_t __evenaccess * )0x000873D2 )
#define ICU_IPR211_ADDR			( ( volatile uint8_t __evenaccess * )0x000873D3 )
#define ICU_IPR212_ADDR			( ( volatile uint8_t __evenaccess * )0x000873D4 )
#define ICU_IPR213_ADDR			( ( volatile uint8_t __evenaccess * )0x000873D5 )
#define ICU_IPR214_ADDR			( ( volatile uint8_t __evenaccess * )0x000873D6 )
#define ICU_IPR215_ADDR			( ( volatile uint8_t __evenaccess * )0x000873D7 )
#define ICU_IPR216_ADDR			( ( volatile uint8_t __evenaccess * )0x000873D8 )
#define ICU_IPR217_ADDR			( ( volatile uint8_t __evenaccess * )0x000873D9 )
#define ICU_IPR218_ADDR			( ( volatile uint8_t __evenaccess * )0x000873DA )
#define ICU_IPR219_ADDR			( ( volatile uint8_t __evenaccess * )0x000873DB )
#define ICU_IPR220_ADDR			( ( volatile uint8_t __evenaccess * )0x000873DC )
#define ICU_IPR221_ADDR			( ( volatile uint8_t __evenaccess * )0x000873DD )
#define ICU_IPR222_ADDR			( ( volatile uint8_t __evenaccess * )0x000873DE )
#define ICU_IPR223_ADDR			( ( volatile uint8_t __evenaccess * )0x000873DF )
#define ICU_IPR224_ADDR			( ( volatile uint8_t __evenaccess * )0x000873E0 )
#define ICU_IPR225_ADDR			( ( volatile uint8_t __evenaccess * )0x000873E1 )
#define ICU_IPR226_ADDR			( ( volatile uint8_t __evenaccess * )0x000873E2 )
#define ICU_IPR227_ADDR			( ( volatile uint8_t __evenaccess * )0x000873E3 )
#define ICU_IPR228_ADDR			( ( volatile uint8_t __evenaccess * )0x000873E4 )
#define ICU_IPR229_ADDR			( ( volatile uint8_t __evenaccess * )0x000873E5 )
#define ICU_IPR230_ADDR			( ( volatile uint8_t __evenaccess * )0x000873E6 )
#define ICU_IPR231_ADDR			( ( volatile uint8_t __evenaccess * )0x000873E7 )
#define ICU_IPR232_ADDR			( ( volatile uint8_t __evenaccess * )0x000873E8 )
#define ICU_IPR233_ADDR			( ( volatile uint8_t __evenaccess * )0x000873E9 )
#define ICU_IPR234_ADDR			( ( volatile uint8_t __evenaccess * )0x000873EA )
#define ICU_IPR235_ADDR			( ( volatile uint8_t __evenaccess * )0x000873EB )
#define ICU_IPR236_ADDR			( ( volatile uint8_t __evenaccess * )0x000873EC )
#define ICU_IPR237_ADDR			( ( volatile uint8_t __evenaccess * )0x000873ED )
#define ICU_IPR238_ADDR			( ( volatile uint8_t __evenaccess * )0x000873EE )
#define ICU_IPR239_ADDR			( ( volatile uint8_t __evenaccess * )0x000873EF )
#define ICU_IPR240_ADDR			( ( volatile uint8_t __evenaccess * )0x000873F0 )
#define ICU_IPR241_ADDR			( ( volatile uint8_t __evenaccess * )0x000873F1 )
#define ICU_IPR242_ADDR			( ( volatile uint8_t __evenaccess * )0x000873F2 )
#define ICU_IPR243_ADDR			( ( volatile uint8_t __evenaccess * )0x000873F3 )
#define ICU_IPR244_ADDR			( ( volatile uint8_t __evenaccess * )0x000873F4 )
#define ICU_IPR245_ADDR			( ( volatile uint8_t __evenaccess * )0x000873F5 )
#define ICU_IPR246_ADDR			( ( volatile uint8_t __evenaccess * )0x000873F6 )
#define ICU_IPR247_ADDR			( ( volatile uint8_t __evenaccess * )0x000873F7 )
#define ICU_IPR248_ADDR			( ( volatile uint8_t __evenaccess * )0x000873F8 )
#define ICU_IPR249_ADDR			( ( volatile uint8_t __evenaccess * )0x000873F9 )
#define ICU_IPR250_ADDR			( ( volatile uint8_t __evenaccess * )0x000873FA )
#define ICU_IPR251_ADDR			( ( volatile uint8_t __evenaccess * )0x000873FB )
#define ICU_IPR252_ADDR			( ( volatile uint8_t __evenaccess * )0x000873FC )
#define ICU_IPR253_ADDR			( ( volatile uint8_t __evenaccess * )0x000873FD )
#define ICU_IPR254_ADDR			( ( volatile uint8_t __evenaccess * )0x000873FE )
#define ICU_IPR255_ADDR			( ( volatile uint8_t __evenaccess * )0x000873FF )
#define ICU_IPR_OFFSET			( 0U )
#define ICU_IPR_MASK			( 0xFU << ICU_IPR_OFFSET )

/*
 *  IRQコントロールレジスタ
 */
#define ICU_IRQ0_ADDR			( ( volatile uint8_t __evenaccess * )0x00087500 )
#define ICU_IRQ1_ADDR			( ( volatile uint8_t __evenaccess * )0x00087501 )
#define ICU_IRQ2_ADDR			( ( volatile uint8_t __evenaccess * )0x00087502 )
#define ICU_IRQ3_ADDR			( ( volatile uint8_t __evenaccess * )0x00087503 )
#define ICU_IRQ4_ADDR			( ( volatile uint8_t __evenaccess * )0x00087504 )
#define ICU_IRQ5_ADDR			( ( volatile uint8_t __evenaccess * )0x00087505 )
#define ICU_IRQ6_ADDR			( ( volatile uint8_t __evenaccess * )0x00087506 )
#define ICU_IRQ7_ADDR			( ( volatile uint8_t __evenaccess * )0x00087507 )
#define ICU_IRQ8_ADDR			( ( volatile uint8_t __evenaccess * )0x00087508 )
#define ICU_IRQ9_ADDR			( ( volatile uint8_t __evenaccess * )0x00087509 )
#define ICU_IRQ10_ADDR			( ( volatile uint8_t __evenaccess * )0x0008750A )
#define ICU_IRQ11_ADDR			( ( volatile uint8_t __evenaccess * )0x0008750B )
#define ICU_IRQ12_ADDR			( ( volatile uint8_t __evenaccess * )0x0008750C )
#define ICU_IRQ13_ADDR			( ( volatile uint8_t __evenaccess * )0x0008750D )
#define ICU_IRQ14_ADDR			( ( volatile uint8_t __evenaccess * )0x0008750E )
#define ICU_IRQ15_ADDR			( ( volatile uint8_t __evenaccess * )0x0008750F )
#define ICU_IRQMD_BIT			( 3U << 2U )


/*
 *  各チャンネルのレジスタ及び設定ビット情報
 */
#define CMT_CMSTR0_ADDR			( ( volatile uint16_t __evenaccess * )0x00088000 )
#define CMT_CMSTR0_STR0_BIT		( 1U << 0U )
#define CMT_CMSTR0_STR1_BIT		( 1U << 1U )
#define CMT_CMSTR1_ADDR			( ( volatile uint16_t __evenaccess * )0x00088010 )
#define CMT_CMSTR1_STR2_BIT		( 1U << 0U )
#define CMT_CMSTR1_STR3_BIT		( 1U << 1U )
#define CMT0_CMCR_ADDR			( ( volatile uint16_t __evenaccess * )0x00088002 )
#define CMT0_CMCR_CKS_BIT		( 3U )
#define CMT0_CMCR_CMIE_BIT		( 1U << 6U )
#define CMT1_CMCR_ADDR			( ( volatile uint16_t __evenaccess * )0x00088008 )
#define CMT1_CMCR_CKS_BIT		( 3U )
#define CMT1_CMCR_CMIE_BIT		( 1U << 6U )
#define CMT2_CMCR_ADDR			( ( volatile uint16_t __evenaccess * )0x00088012 )
#define CMT2_CMCR_CKS_BIT		( 3U)
#define CMT2_CMCR_CMIE_BIT		( 1U << 6U )
#define CMT3_CMCR_ADDR			( ( volatile uint16_t __evenaccess * )0x00088018 )
#define CMT3_CMCR_CKS_BIT		( 3U )
#define CMT3_CMCR_CMIE_BIT		( 1U << 6U )
#define CMT0_CMCNT_ADDR			( ( volatile uint16_t __evenaccess * )0x00088004 )
#define CMT1_CMCNT_ADDR			( ( volatile uint16_t __evenaccess * )0x0008800A )
#define CMT2_CMCNT_ADDR			( ( volatile uint16_t __evenaccess * )0x00088014 )
#define CMT3_CMCNT_ADDR			( ( volatile uint16_t __evenaccess * )0x0008801A )
#define CMT0_CMCOR_ADDR			( ( volatile uint16_t __evenaccess * )0x00088006 )
#define CMT1_CMCOR_ADDR			( ( volatile uint16_t __evenaccess * )0x0008800C )
#define CMT2_CMCOR_ADDR			( ( volatile uint16_t __evenaccess * )0x00088016 )
#define CMT3_CMCOR_ADDR			( ( volatile uint16_t __evenaccess * )0x0008801C )

#define SCI0_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A000 )
#define SCI0_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A001 )
#define SCI0_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A002 )
#define SCI0_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A003 )
#define SCI0_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A004 )
#define SCI0_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A005 )
#define SCI0_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A006 )
#define SCI0_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A007 )
#define SCI1_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A020 )
#define SCI1_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A021 )
#define SCI1_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A022 )
#define SCI1_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A023 )
#define SCI1_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A024 )
#define SCI1_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A025 )
#define SCI1_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A026 )
#define SCI1_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A027 )
#define SCI2_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A040 )
#define SCI2_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A041 )
#define SCI2_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A042 )
#define SCI2_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A043 )
#define SCI2_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A044 )
#define SCI2_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A045 )
#define SCI2_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A046 )
#define SCI2_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A047 )
#define SCI3_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A060 )
#define SCI3_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A061 )
#define SCI3_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A062 )
#define SCI3_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A063 )
#define SCI3_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A064 )
#define SCI3_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A065 )
#define SCI3_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A066 )
#define SCI3_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A067 )
#define SCI4_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A080 )
#define SCI4_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A081 )
#define SCI4_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A082 )
#define SCI4_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A083 )
#define SCI4_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A084 )
#define SCI4_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A085 )
#define SCI4_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A086 )
#define SCI4_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A087 )
#define SCI5_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0A0 )
#define SCI5_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0A1 )
#define SCI5_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0A2 )
#define SCI5_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0A3 )
#define SCI5_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0A4 )
#define SCI5_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0A5 )
#define SCI5_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0A6 )
#define SCI5_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0A7 )
#define SCI6_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0C0 )
#define SCI6_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0C1 )
#define SCI6_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0C2 )
#define SCI6_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0C3 )
#define SCI6_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0C4 )
#define SCI6_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0C5 )
#define SCI6_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0C6 )
#define SCI6_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0C7 )
#define SCI7_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0E0 )
#define SCI7_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0E1 )
#define SCI7_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0E2 )
#define SCI7_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0E3 )
#define SCI7_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0E4 )
#define SCI7_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0E5 )
#define SCI7_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0E6 )
#define SCI7_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A0E7 )
#define SCI8_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A100 )
#define SCI8_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A101 )
#define SCI8_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A102 )
#define SCI8_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A103 )
#define SCI8_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A104 )
#define SCI8_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A105 )
#define SCI8_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A106 )
#define SCI8_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A107 )
#define SCI9_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A120 )
#define SCI9_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A121 )
#define SCI9_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A122 )
#define SCI9_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A123 )
#define SCI9_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A124 )
#define SCI9_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A125 )
#define SCI9_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A126 )
#define SCI9_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A127 )
#define SCI10_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A140 )
#define SCI10_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A141 )
#define SCI10_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A142 )
#define SCI10_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A143 )
#define SCI10_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A144 )
#define SCI10_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A145 )
#define SCI10_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A146 )
#define SCI10_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A147 )
#define SCI11_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A160 )
#define SCI11_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A161 )
#define SCI11_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A162 )
#define SCI11_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A163 )
#define SCI11_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A164 )
#define SCI11_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A165 )
#define SCI11_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A166 )
#define SCI11_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A167 )
#define SCI12_SMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A300 )
#define SCI12_BRR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A301 )
#define SCI12_SCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A302 )
#define SCI12_TDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A303 )
#define SCI12_SSR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A304 )
#define SCI12_RDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A305 )
#define SCI12_SCMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A306 )
#define SCI12_SEMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008A307 )
#define SCI_SMR_CKS_BIT			( 3U << 0U )
#define SCI_SMR_STOP_BIT		( 1U << 3U )
#define SCI_SMR_PM_BIT			( 1U << 4U )
#define SCI_SMR_PE_BIT			( 1U << 5U )
#define SCI_SMR_CHR_BIT			( 1U << 6U )
#define SCI_SMR_CM_BIT			( 1U << 7U )
#define SCI_SCR_CKE_BIT			( 3U << 0U )
#define SCI_SCR_TEIE_BIT		( 1U << 2U )
#define SCI_SCR_RE_BIT			( 1U << 4U )
#define SCI_SCR_TE_BIT			( 1U << 5U )
#define SCI_SCR_RIE_BIT			( 1U << 6U )
#define SCI_SCR_TIE_BIT			( 1U << 7U )
#define SCI_SSR_TEND_BIT		( 1U << 2U )
#define SCI_SSR_PER_BIT			( 1U << 3U )
#define SCI_SSR_FER_BIT			( 1U << 4U )
#define SCI_SSR_ORER_BIT		( 1U << 5U )
#define SCI_SCMR_SMIF_BIT		( 1U << 0U )
#define SCI_SCMR_SINV_BIT		( 1U << 2U )
#define SCI_SCMR_SDIR_BIT		( 1U << 3U )
#define SCI_SCMR_BCP2_BIT		( 1U << 7U )
#define SCI_SEMR_ACS0_BIT		( 1U << 0U )
#define SCI_SEMR_ABCS_BIT		( 1U << 4U )

/*
 *  I/Oポートのレジスタ及び設定ビット情報
 */
#define PORT0_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C000 )
#define PORT1_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C001 )
#define PORT2_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C002 )
#define PORT3_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C003 )
#define PORT4_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C004 )
#define PORT5_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C005 )
#define PORT6_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C006 )
#define PORT7_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C007 )
#define PORT8_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C008 )
#define PORT9_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C009 )
#define PORTA_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C00A )
#define PORTB_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C00B )
#define PORTC_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C00C )
#define PORTD_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C00D )
#define PORTE_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C00E )
#define PORTF_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C00F )
#define PORTG_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C010 )
#define PORTJ_PDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C012 )
#define PORT_PDR_B0_BIT			( 0x01U << 0U )
#define PORT_PDR_B1_BIT			( 0x01U << 1U )
#define PORT_PDR_B2_BIT			( 0x01U << 2U )
#define PORT_PDR_B3_BIT			( 0x01U << 3U )
#define PORT_PDR_B4_BIT			( 0x01U << 4U )
#define PORT_PDR_B5_BIT			( 0x01U << 5U )
#define PORT_PDR_B6_BIT			( 0x01U << 6U )
#define PORT_PDR_B7_BIT			( 0x01U << 7U )
#define PORT0_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C020 )
#define PORT1_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C021 )
#define PORT2_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C022 )
#define PORT3_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C023 )
#define PORT4_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C024 )
#define PORT5_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C025 )
#define PORT6_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C026 )
#define PORT7_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C027 )
#define PORT8_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C028 )
#define PORT9_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C029 )
#define PORTA_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C02A )
#define PORTB_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C02B )
#define PORTC_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C02C )
#define PORTD_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C02D )
#define PORTE_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C02E )
#define PORTF_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C02F )
#define PORTG_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C030 )
#define PORTJ_PODR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C032 )
#define PORT_PODR_B0_BIT		( 0x01U << 0U )
#define PORT_PODR_B1_BIT		( 0x01U << 1U )
#define PORT_PODR_B2_BIT		( 0x01U << 2U )
#define PORT_PODR_B3_BIT		( 0x01U << 3U )
#define PORT_PODR_B4_BIT		( 0x01U << 4U )
#define PORT_PODR_B5_BIT		( 0x01U << 5U )
#define PORT_PODR_B6_BIT		( 0x01U << 6U )
#define PORT_PODR_B7_BIT		( 0x01U << 7U )
#define PORT0_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C040 )
#define PORT1_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C041 )
#define PORT2_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C042 )
#define PORT3_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C043 )
#define PORT4_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C044 )
#define PORT5_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C045 )
#define PORT6_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C046 )
#define PORT7_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C047 )
#define PORT8_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C048 )
#define PORT9_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C049 )
#define PORTA_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C04A )
#define PORTB_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C04B )
#define PORTC_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C04C )
#define PORTD_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C04D )
#define PORTE_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C04E )
#define PORTF_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C04F )
#define PORTG_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C050 )
#define PORTJ_PIDR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C052 )
#define PORT_PIDR_B0_BIT		( 0x01U << 0U )
#define PORT_PIDR_B1_BIT		( 0x01U << 1U )
#define PORT_PIDR_B2_BIT		( 0x01U << 2U )
#define PORT_PIDR_B3_BIT		( 0x01U << 3U )
#define PORT_PIDR_B4_BIT		( 0x01U << 4U )
#define PORT_PIDR_B5_BIT		( 0x01U << 5U )
#define PORT_PIDR_B6_BIT		( 0x01U << 6U )
#define PORT_PIDR_B7_BIT		( 0x01U << 7U )
#define PORT0_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C060 )
#define PORT1_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C061 )
#define PORT2_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C062 )
#define PORT3_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C063 )
#define PORT4_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C064 )
#define PORT5_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C065 )
#define PORT6_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C066 )
#define PORT7_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C067 )
#define PORT8_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C068 )
#define PORT9_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C069 )
#define PORTA_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C06A )
#define PORTB_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C06B )
#define PORTC_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C06C )
#define PORTD_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C06D )
#define PORTE_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C06E )
#define PORTF_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C06F )
#define PORTG_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C070 )
#define PORTJ_PMR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C072 )
#define PORT_PMR_B0_BIT			( 0x01U << 0U )
#define PORT_PMR_B1_BIT			( 0x01U << 1U )
#define PORT_PMR_B2_BIT			( 0x01U << 2U )
#define PORT_PMR_B3_BIT			( 0x01U << 3U )
#define PORT_PMR_B4_BIT			( 0x01U << 4U )
#define PORT_PMR_B5_BIT			( 0x01U << 5U )
#define PORT_PMR_B6_BIT			( 0x01U << 6U )
#define PORT_PMR_B7_BIT			( 0x01U << 7U )
#define PORT0_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0C0 )
#define PORT1_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0C1 )
#define PORT2_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0C2 )
#define PORT3_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0C3 )
#define PORT4_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0C4 )
#define PORT5_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0C5 )
#define PORT6_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0C6 )
#define PORT7_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0C7 )
#define PORT8_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0C8 )
#define PORT9_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0C9 )
#define PORTA_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0CA )
#define PORTB_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0CB )
#define PORTC_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0CC )
#define PORTD_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0CD )
#define PORTE_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0CE )
#define PORTF_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0CF )
#define PORTG_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0D0 )
#define PORTJ_PCR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0D2 )
#define PORT_PCR_B0_BIT			( 0x01U << 0U )
#define PORT_PCR_B1_BIT			( 0x01U << 1U )
#define PORT_PCR_B2_BIT			( 0x01U << 2U )
#define PORT_PCR_B3_BIT			( 0x01U << 3U )
#define PORT_PCR_B4_BIT			( 0x01U << 4U )
#define PORT_PCR_B5_BIT			( 0x01U << 5U )
#define PORT_PCR_B6_BIT			( 0x01U << 6U )
#define PORT_PCR_B7_BIT			( 0x01U << 7U )
#define PORT0_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C080 )
#define PORT1_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C082 )
#define PORT2_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C084 )
#define PORT3_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C086 )
#define PORT4_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C088 )
#define PORT5_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C08A )
#define PORT6_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C08C )
#define PORT7_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C08E )
#define PORT8_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C090 )
#define PORT9_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C092 )
#define PORTA_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C094 )
#define PORTB_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C096 )
#define PORTC_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C098 )
#define PORTD_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C09A )
#define PORTE_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C09C )
#define PORTF_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C09E )
#define PORTG_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0A0 )
#define PORTJ_ODR0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0A4 )
#define PORT0_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C081 )
#define PORT1_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C083 )
#define PORT2_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C085 )
#define PORT3_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C087 )
#define PORT4_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C089 )
#define PORT5_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C08B )
#define PORT6_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C08D )
#define PORT7_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C08F )
#define PORT8_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C091 )
#define PORT9_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C093 )
#define PORTA_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C095 )
#define PORTB_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C097 )
#define PORTC_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C099 )
#define PORTD_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C09B )
#define PORTE_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C09D )
#define PORTF_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C09F )
#define PORTG_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0A1 )
#define PORTJ_ODR1_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C0A5 )
#define PORT_ODR_Pm0_OFFSET		( 0U )
#define PORT_ODR_Pm0_MASK		( 0x3U << PORT_ODR_Pm0_OFFSET )
#define PORT_ODR_Pm1_OFFSET		( 2U )
#define PORT_ODR_Pm1_MASK		( 0x3U << PORT_ODR_Pm1_OFFSET )
#define PORT_ODR_Pm2_OFFSET		( 4U )
#define PORT_ODR_Pm2_MASK		( 0x3U << PORT_ODR_Pm2_OFFSET )
#define PORT_ODR_Pm3_OFFSET		( 6U )
#define PORT_ODR_Pm3_MASK		( 0x3U << PORT_ODR_Pm3_OFFSET )
#define PORT_ODR_Pm4_OFFSET		( 0U )
#define PORT_ODR_Pm4_MASK		( 0x3U << PORT_ODR_Pm4_OFFSET )
#define PORT_ODR_Pm5_OFFSET		( 2U )
#define PORT_ODR_Pm5_MASK		( 0x3U << PORT_ODR_Pm5_OFFSET )
#define PORT_ODR_Pm6_OFFSET		( 4U )
#define PORT_ODR_Pm6_MASK		( 0x3U << PORT_ODR_Pm6_OFFSET )
#define PORT_ODR_Pm7_OFFSET		( 6U )
#define PORT_ODR_Pm7_MASK		( 0x3U << PORT_ODR_Pm7_OFFSET )
#define PORT_ODR_CMOS			( 0U )
#define PORT_ODR_NCH_OPEN_DRAIN	( 1U )
#define PORT_ODR_PCH_OPEN_DRAIN	( 2U )

/*
 *  マルチファンクションピンコントローラのレジスタ情報
 */
#define MPC_PFUSB0_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C114 )
#define MPC_PFUSB0_PDHZS_BIT	( 0x01U << 2U )
#define MPC_PFUSB0_PUPHZS_BIT	( 0x01U << 3U )
#define MPC_PWPR_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C11F )
#define MPC_PWPR_PFSWE			( 0x01U << 6U )
#define MPC_PWPR_B0WI			( 0x01U << 7U )
#define MPC_P00PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C140 )
#define MPC_P01PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C141 )
#define MPC_P02PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C142 )
#define MPC_P03PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C143 )
#define MPC_P04PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C144 )
#define MPC_P05PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C145 )
#define MPC_P06PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C146 )
#define MPC_P07PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C147 )
#define MPC_P10PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C148 )
#define MPC_P11PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C149 )
#define MPC_P12PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C14A )
#define MPC_P13PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C14B )
#define MPC_P14PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C14C )
#define MPC_P15PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C14D )
#define MPC_P16PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C14E )
#define MPC_P17PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C14F )
#define MPC_P20PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C150 )
#define MPC_P21PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C151 )
#define MPC_P22PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C152 )
#define MPC_P23PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C153 )
#define MPC_P24PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C154 )
#define MPC_P25PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C155 )
#define MPC_P26PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C156 )
#define MPC_P27PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C157 )
#define MPC_P30PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C158 )
#define MPC_P31PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C159 )
#define MPC_P32PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C15A )
#define MPC_P33PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C15B )
#define MPC_P34PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C15C )
#define MPC_P35PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C15D )
#define MPC_P36PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C15E )
#define MPC_P37PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C15F )
#define MPC_P40PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C160 )
#define MPC_P41PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C161 )
#define MPC_P42PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C162 )
#define MPC_P43PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C163 )
#define MPC_P44PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C164 )
#define MPC_P45PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C165 )
#define MPC_P46PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C166 )
#define MPC_P47PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C167 )
#define MPC_P50PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C168 )
#define MPC_P51PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C169 )
#define MPC_P52PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C16A )
#define MPC_P53PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C16B )
#define MPC_P54PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C16C )
#define MPC_P55PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C16D )
#define MPC_P56PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C16E )
#define MPC_P57PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C16F )
#define MPC_P60PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C170 )
#define MPC_P61PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C171 )
#define MPC_P62PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C172 )
#define MPC_P63PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C173 )
#define MPC_P64PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C174 )
#define MPC_P65PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C175 )
#define MPC_P66PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C176 )
#define MPC_P67PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C177 )
#define MPC_P70PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C178 )
#define MPC_P71PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C179 )
#define MPC_P72PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C17A )
#define MPC_P73PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C17B )
#define MPC_P74PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C17C )
#define MPC_P75PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C17D )
#define MPC_P76PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C17E )
#define MPC_P77PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C17F )
#define MPC_P80PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C180 )
#define MPC_P81PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C181 )
#define MPC_P82PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C182 )
#define MPC_P83PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C183 )
#define MPC_P84PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C184 )
#define MPC_P85PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C185 )
#define MPC_P86PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C186 )
#define MPC_P87PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C187 )
#define MPC_P90PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C188 )
#define MPC_P91PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C189 )
#define MPC_P92PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C18A )
#define MPC_P93PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C18B )
#define MPC_P94PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C18C )
#define MPC_P95PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C18D )
#define MPC_P96PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C18E )
#define MPC_P97PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C18F )
#define MPC_PA0PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C190 )
#define MPC_PA1PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C191 )
#define MPC_PA2PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C192 )
#define MPC_PA3PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C193 )
#define MPC_PA4PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C194 )
#define MPC_PA5PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C195 )
#define MPC_PA6PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C196 )
#define MPC_PA7PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C197 )
#define MPC_PB0PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C198 )
#define MPC_PB1PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C199 )
#define MPC_PB2PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C19A )
#define MPC_PB3PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C19B )
#define MPC_PB4PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C19C )
#define MPC_PB5PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C19D )
#define MPC_PB6PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C19E )
#define MPC_PB7PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C19F )
#define MPC_PC0PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1A0 )
#define MPC_PC1PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1A1 )
#define MPC_PC2PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1A2 )
#define MPC_PC3PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1A3 )
#define MPC_PC4PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1A4 )
#define MPC_PC5PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1A5 )
#define MPC_PC6PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1A6 )
#define MPC_PC7PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1A7 )
#define MPC_PD0PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1A8 )
#define MPC_PD1PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1A9 )
#define MPC_PD2PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1AA )
#define MPC_PD3PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1AB )
#define MPC_PD4PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1AC )
#define MPC_PD5PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1AD )
#define MPC_PD6PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1AE )
#define MPC_PD7PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1AF )
#define MPC_PE0PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1B0 )
#define MPC_PE1PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1B1 )
#define MPC_PE2PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1B2 )
#define MPC_PE3PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1B3 )
#define MPC_PE4PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1B4 )
#define MPC_PE5PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1B5 )
#define MPC_PE6PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1B6 )
#define MPC_PE7PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1B7 )
#define MPC_PF0PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1B8 )
#define MPC_PF1PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1B9 )
#define MPC_PF2PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1BA )
#define MPC_PF3PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1BB )
#define MPC_PF4PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1BC )
#define MPC_PF5PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1BD )
#define MPC_PF6PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1BE )
#define MPC_PF7PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1BF )
#define MPC_PJ3PFS_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C1D3 )

/*
 * リアルタイムクロック
 */
#define RTC_R64CNT_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C400 )
#define RTC_RSECCNT_ADDR		( ( volatile uint8_t __evenaccess * )0x0008C402 )
#define RTC_RMINCNT_ADDR		( ( volatile uint8_t __evenaccess * )0x0008C404 )
#define RTC_RHRCNT_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C406 )
#define RTC_RWKCNT_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C408 )
#define RTC_RDAYCNT_ADDR		( ( volatile uint8_t __evenaccess * )0x0008C40A )
#define RTC_RMONCNT_ADDR		( ( volatile uint8_t __evenaccess * )0x0008C40C )
#define RTC_RYRCNT_ADDR			( ( volatile uint8_t __evenaccess * )0x0008C40E )

/*
 * 12 ビットA/D コンバータ
 */
#define S12AD_ADCSR_ADDR		( ( volatile uint8_t __evenaccess * )0x00089000 )
#define S12AD_ADCSR_ADST_BIT	0x80
#define S12AD_ADANS0_ADDR		( ( volatile uint16_t __evenaccess * )0x00089004 )
#define S12AD_ADANS1_ADDR		( ( volatile uint16_t __evenaccess * )0x00089006 )
#define S12AD_ADEXICR_ADDR		( ( volatile uint16_t __evenaccess * )0x00089012 )
#define S12AD_ADDR0_ADDR		( ( volatile uint16_t __evenaccess * )0x00089020 )
#define S12AD_ADDR1_ADDR		( ( volatile uint16_t __evenaccess * )0x00089022 )
#define S12AD_ADDR2_ADDR		( ( volatile uint16_t __evenaccess * )0x00089024 )
#define S12AD_ADDR3_ADDR		( ( volatile uint16_t __evenaccess * )0x00089026 )
#define S12AD_ADDR4_ADDR		( ( volatile uint16_t __evenaccess * )0x00089028 )
#define S12AD_ADDR5_ADDR		( ( volatile uint16_t __evenaccess * )0x0008902A )
#define S12AD_ADDR6_ADDR		( ( volatile uint16_t __evenaccess * )0x0008902C )
#define S12AD_ADDR7_ADDR		( ( volatile uint16_t __evenaccess * )0x0008902E )
#define S12AD_ADDR8_ADDR		( ( volatile uint16_t __evenaccess * )0x00089030 )
#define S12AD_ADDR9_ADDR		( ( volatile uint16_t __evenaccess * )0x00089032 )
#define S12AD_ADDR10_ADDR		( ( volatile uint16_t __evenaccess * )0x00089034 )
#define S12AD_ADDR11_ADDR		( ( volatile uint16_t __evenaccess * )0x00089036 )
#define S12AD_ADDR12_ADDR		( ( volatile uint16_t __evenaccess * )0x00089038 )
#define S12AD_ADDR13_ADDR		( ( volatile uint16_t __evenaccess * )0x0008903A )
#define S12AD_ADDR14_ADDR		( ( volatile uint16_t __evenaccess * )0x0008903C )
#define S12AD_ADDR15_ADDR		( ( volatile uint16_t __evenaccess * )0x0008903E )
#define S12AD_ADDR16_ADDR		( ( volatile uint16_t __evenaccess * )0x00089040 )
#define S12AD_ADDR17_ADDR		( ( volatile uint16_t __evenaccess * )0x00089042 )
#define S12AD_ADDR18_ADDR		( ( volatile uint16_t __evenaccess * )0x00089044 )
#define S12AD_ADDR19_ADDR		( ( volatile uint16_t __evenaccess * )0x00089046 )
#define S12AD_ADDR20_ADDR		( ( volatile uint16_t __evenaccess * )0x00089048 )

#define TPU0_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088110 )
#define TPU1_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088120 )
#define TPU2_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088130 )
#define TPU3_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088140 )
#define TPU4_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088150 )
#define TPU5_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088160 )
#define TPU6_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088180 )
#define TPU7_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088190 )
#define TPU8_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881A0 )
#define TPU9_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881B0 )
#define TPU10_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881C0 )
#define TPU11_TCR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881D0 )
#define TPU_TCR_TPSC_OFFSET		( 0U )
#define TPU_TCR_TPSC_MASK		( 0x7U << TPU_TCR_TPSC_OFFSET )
#define TPU_TCR_CKEG_OFFSET		( 3U )
#define TPU_TCR_CKEG_MASK		( 0x3U << TPU_TCR_CKEG_OFFSET )
#define TPU_TCR_CCLR_OFFSET		( 5U )
#define TPU_TCR_CCLR_MASK		( 0x7U << TPU_TCR_CCLR_OFFSET )

#define TPU0_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088111 )
#define TPU1_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088121 )
#define TPU2_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088131 )
#define TPU3_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088141 )
#define TPU4_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088151 )
#define TPU5_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088161 )
#define TPU6_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088181 )
#define TPU7_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088191 )
#define TPU8_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881A1 )
#define TPU9_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881B1 )
#define TPU10_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881C1 )
#define TPU11_TMDR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881D1 )
#define TPU_TMDR_MD_OFFSET		( 0U )
#define TPU_TMDR_MD_MASK		( 0xFU << TPU_TMDR_MD_OFFSET )
#define TPU_TMDR_BFA_BIT		( 0x10 )
#define TPU_TMDR_BFB_BIT		( 0x20 )
#define TPU_TMDR_ICSELB_BIT		( 0x40 )
#define TPU_TMDR_ICSELD_BIT		( 0x80 )

#define TPU0_TIOR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881C0 )
#define TPU0_TIORH_ADDR			( ( volatile uint8_t __evenaccess * )0x00088112 )
#define TPU0_TIORL_ADDR			( ( volatile uint8_t __evenaccess * )0x00088113 )
#define TPU1_TIOR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088122 )
#define TPU2_TIOR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088132 )
#define TPU3_TIORH_ADDR			( ( volatile uint8_t __evenaccess * )0x00088142 )
#define TPU3_TIORL_ADDR			( ( volatile uint8_t __evenaccess * )0x00088143 )
#define TPU4_TIOR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088152 )
#define TPU5_TIOR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088162 )
#define TPU6_TIORH_ADDR			( ( volatile uint8_t __evenaccess * )0x00088182 )
#define TPU6_TIORL_ADDR			( ( volatile uint8_t __evenaccess * )0x00088183 )
#define TPU7_TIOR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088192 )
#define TPU8_TIOR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881A2 )
#define TPU9_TIORH_ADDR			( ( volatile uint8_t __evenaccess * )0x000881B2 )
#define TPU9_TIORL_ADDR			( ( volatile uint8_t __evenaccess * )0x000881B3 )
#define TPU10_TIOR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881C2 )
#define TPU11_TIOR_ADDR			( ( volatile uint8_t __evenaccess * )0x000881D2 )
#define TPU_TIOR_IOA_OFFSET	( 0U )
#define TPU_TIOR_IOA_MASK		( 0xFU << TPU_TIOR_IOA_OFFSET )
#define TPU_TIOR_IOB_OFFSET	( 4U )
#define TPU_TIOR_IOB_MASK		( 0xFU << TPU_TIOR_IOB_OFFSET )
#define TPU_TIORH_IOA_OFFSET	( 0U )
#define TPU_TIORH_IOA_MASK		( 0xFU << TPU_TIORH_IOA_OFFSET )
#define TPU_TIORH_IOB_OFFSET	( 4U )
#define TPU_TIORH_IOB_MASK		( 0xFU << TPU_TIORH_IOB_OFFSET )
#define TPU_TIORL_IOC_OFFSET	( 0U )
#define TPU_TIORL_IOC_MASK		( 0xFU << TPU_TIORL_IOC_OFFSET )
#define TPU_TIORL_IOD_OFFSET	( 4U )
#define TPU_TIORL_IOD_MASK		( 0xFU << TPU_TIORL_IOD_OFFSET )

#define TPU0_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x00088118 )
#define TPU0_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x0008811A )
#define TPU0_TGRC_ADDR			( ( volatile uint16_t __evenaccess * )0x0008811C )
#define TPU0_TGRD_ADDR			( ( volatile uint16_t __evenaccess * )0x0008811E )
#define TPU1_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x00088128 )
#define TPU1_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x0008812A )
#define TPU2_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x00088138 )
#define TPU2_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x0008813A )
#define TPU3_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x00088148 )
#define TPU3_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x0008814A )
#define TPU3_TGRC_ADDR			( ( volatile uint16_t __evenaccess * )0x0008814C )
#define TPU3_TGRD_ADDR			( ( volatile uint16_t __evenaccess * )0x0008814E )
#define TPU4_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x00088158 )
#define TPU4_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x0008815A )
#define TPU5_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x00088168 )
#define TPU5_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x0008816A )
#define TPU6_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x00088188 )
#define TPU6_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x0008818A )
#define TPU6_TGRC_ADDR			( ( volatile uint16_t __evenaccess * )0x0008818C )
#define TPU6_TGRD_ADDR			( ( volatile uint16_t __evenaccess * )0x0008818E )
#define TPU7_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x00088198 )
#define TPU7_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x0008819A )
#define TPU8_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x000881A8 )
#define TPU8_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x000881AA )
#define TPU9_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x000881B8 )
#define TPU9_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x000881BA )
#define TPU9_TGRC_ADDR			( ( volatile uint16_t __evenaccess * )0x000881BC )
#define TPU9_TGRD_ADDR			( ( volatile uint16_t __evenaccess * )0x000881BE )
#define TPU10_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x000881C8 )
#define TPU10_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x000881CA )
#define TPU11_TGRA_ADDR			( ( volatile uint16_t __evenaccess * )0x000881D8 )
#define TPU11_TGRB_ADDR			( ( volatile uint16_t __evenaccess * )0x000881DA )

#define TPUA_TSTR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088100 )
#define TPUB_TSTR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088170 )
#define TPU_TSTR_CST0_BIT		( 0x01U << 0U )
#define TPU_TSTR_CST1_BIT		( 0x01U << 1U )
#define TPU_TSTR_CST2_BIT		( 0x01U << 2U )
#define TPU_TSTR_CST3_BIT		( 0x01U << 3U )
#define TPU_TSTR_CST4_BIT		( 0x01U << 4U )
#define TPU_TSTR_CST5_BIT		( 0x01U << 5U )

#define TPUA_TSYR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088101 )
#define TPUB_TSYR_ADDR			( ( volatile uint8_t __evenaccess * )0x00088171 )
#define TPU_TSYR_SYNC0_BIT		( 0x01U << 0U )
#define TPU_TSYR_SYNC1_BIT		( 0x01U << 1U )
#define TPU_TSYR_SYNC2_BIT		( 0x01U << 2U )
#define TPU_TSYR_SYNC3_BIT		( 0x01U << 3U )
#define TPU_TSYR_SYNC4_BIT		( 0x01U << 4U )
#define TPU_TSYR_SYNC5_BIT		( 0x01U << 5U )

#define TPU0_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x00088114 )
#define TPU1_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x00088124 )
#define TPU2_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x00088134 )
#define TPU3_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x00088144 )
#define TPU4_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x00088154 )
#define TPU5_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x00088164 )
#define TPU6_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x00088184 )
#define TPU7_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x00088194 )
#define TPU8_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x000881A4 )
#define TPU9_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x000881B4 )
#define TPU10_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x000881C4 )
#define TPU11_TIER_ADDR			( ( volatile uint8_t __evenaccess *)0x000881D4 )

#define TPU0_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x00088116 )
#define TPU1_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x00088126 )
#define TPU2_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x00088136 )
#define TPU3_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x00088146 )
#define TPU4_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x00088156 )
#define TPU5_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x00088166 )
#define TPU6_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x00088186 )
#define TPU7_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x00088196 )
#define TPU8_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x000881A6 )
#define TPU9_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x000881B6 )
#define TPU10_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x000881C6 )
#define TPU11_TCNT_ADDR			( ( volatile uint16_t __evenaccess *)0x000881D6 )

/*
 * RSPI
 */
#define RSPI0_SPCR_ADDR		( ( volatile uint8_t __evenaccess * )0x00088380 )
#define RSPI1_SPCR_ADDR		( ( volatile uint8_t __evenaccess * )0x000883A0 )
#define RSPI2_SPCR_ADDR		( ( volatile uint8_t __evenaccess * )0x000883C0 )
#define RSPI_SPCR_SPMS_BIT	( 0x01U << 0U )
#define RSPI_SPCR_TXMD_BIT	( 0x01U << 1U )
#define RSPI_SPCR_MODFEN_BIT	( 0x01U << 2U )
#define RSPI_SPCR_MSTR_BIT	( 0x01U << 3U )
#define RSPI_SPCR_SPEIE_BIT	( 0x01U << 4U )
#define RSPI_SPCR_SPTIE_BIT	( 0x01U << 5U )
#define RSPI_SPCR_SPE_BIT	( 0x01U << 6U )
#define RSPI_SPCR_SPRIE_BIT	( 0x01U << 7U )

#define RSPI0_SSLP_ADDR		( ( volatile uint8_t __evenaccess * )0x00088381 )
#define RSPI1_SSLP_ADDR		( ( volatile uint8_t __evenaccess * )0x000883A1 )
#define RSPI2_SSLP_ADDR		( ( volatile uint8_t __evenaccess * )0x000883C1 )

#define RSPI0_SPPCR_ADDR	( ( volatile uint8_t __evenaccess * )0x00088382 )
#define RSPI1_SPPCR_ADDR	( ( volatile uint8_t __evenaccess * )0x000883A2 )
#define RSPI2_SPPCR_ADDR	( ( volatile uint8_t __evenaccess * )0x000883C2 )

#define RSPI0_SPSR_ADDR		( ( volatile uint8_t __evenaccess * )0x00088383 )
#define RSPI1_SPSR_ADDR		( ( volatile uint8_t __evenaccess * )0x000883A3 )
#define RSPI2_SPSR_ADDR		( ( volatile uint8_t __evenaccess * )0x000883C3 )

#define RSPI0_SPDR_ADDR		( ( volatile uint32_t __evenaccess * )0x00088384 )
#define RSPI1_SPDR_ADDR		( ( volatile uint32_t __evenaccess * )0x000883A4 )
#define RSPI2_SPDR_ADDR		( ( volatile uint32_t __evenaccess * )0x000883C4 )

#define RSPI0_SPSCR_ADDR	( ( volatile uint8_t __evenaccess * )0x00088388 )
#define RSPI1_SPSCR_ADDR	( ( volatile uint8_t __evenaccess * )0x000883A8 )
#define RSPI2_SPSCR_ADDR	( ( volatile uint8_t __evenaccess * )0x000883C8 )

#define RSPI0_SPSSR_ADDR	( ( volatile uint8_t __evenaccess * )0x00088389 )
#define RSPI1_SPSSR_ADDR	( ( volatile uint8_t __evenaccess * )0x000883A9 )
#define RSPI2_SPSSR_ADDR	( ( volatile uint8_t __evenaccess * )0x000883C9 )

#define RSPI0_SPBR_ADDR		( ( volatile uint8_t __evenaccess * )0x0008838A )
#define RSPI1_SPBR_ADDR		( ( volatile uint8_t __evenaccess * )0x000883AA )
#define RSPI2_SPBR_ADDR		( ( volatile uint8_t __evenaccess * )0x000883CA )

#define RSPI0_SPDCR_ADDR	( ( volatile uint8_t __evenaccess * )0x0008838B )
#define RSPI1_SPDCR_ADDR	( ( volatile uint8_t __evenaccess * )0x000883AB )
#define RSPI2_SPDCR_ADDR	( ( volatile uint8_t __evenaccess * )0x000883CB )

#define RSPI0_SPCKD_ADDR	( ( volatile uint8_t __evenaccess * )0x0008838C )
#define RSPI1_SPCKD_ADDR	( ( volatile uint8_t __evenaccess * )0x000883AC )
#define RSPI2_SPCKD_ADDR	( ( volatile uint8_t __evenaccess * )0x000883CC )

#define RSPI0_SSLND_ADDR	( ( volatile uint8_t __evenaccess * )0x0008838D )
#define RSPI1_SSLND_ADDR	( ( volatile uint8_t __evenaccess * )0x000883AD )
#define RSPI2_SSLND_ADDR	( ( volatile uint8_t __evenaccess * )0x000883CD )

#define RSPI0_SPND_ADDR		( ( volatile uint8_t __evenaccess * )0x0008838E )
#define RSPI1_SPND_ADDR		( ( volatile uint8_t __evenaccess * )0x000883AE )
#define RSPI2_SPND_ADDR		( ( volatile uint8_t __evenaccess * )0x000883CE )

#define RSPI0_SPCR2_ADDR	( ( volatile uint8_t __evenaccess * )0x0008838F )
#define RSPI1_SPCR2_ADDR	( ( volatile uint8_t __evenaccess * )0x000883AF )
#define RSPI2_SPCR2_ADDR	( ( volatile uint8_t __evenaccess * )0x000883CF )

#define RSPI0_SPCMD0_ADDR	( ( volatile uint16_t __evenaccess * )0x00088390 )
#define RSPI0_SPCMD1_ADDR	( ( volatile uint16_t __evenaccess * )0x00088392 )
#define RSPI0_SPCMD2_ADDR	( ( volatile uint16_t __evenaccess * )0x00088394 )
#define RSPI0_SPCMD3_ADDR	( ( volatile uint16_t __evenaccess * )0x00088396 )
#define RSPI0_SPCMD4_ADDR	( ( volatile uint16_t __evenaccess * )0x00088398 )
#define RSPI0_SPCMD5_ADDR	( ( volatile uint16_t __evenaccess * )0x0008839A )
#define RSPI0_SPCMD6_ADDR	( ( volatile uint16_t __evenaccess * )0x0008839C )
#define RSPI0_SPCMD7_ADDR	( ( volatile uint16_t __evenaccess * )0x0008839E )
#define RSPI1_SPCMD0_ADDR	( ( volatile uint16_t __evenaccess * )0x000883B0 )
#define RSPI1_SPCMD1_ADDR	( ( volatile uint16_t __evenaccess * )0x000883B2 )
#define RSPI1_SPCMD2_ADDR	( ( volatile uint16_t __evenaccess * )0x000883B4 )
#define RSPI1_SPCMD3_ADDR	( ( volatile uint16_t __evenaccess * )0x000883B6 )
#define RSPI1_SPCMD4_ADDR	( ( volatile uint16_t __evenaccess * )0x000883B8 )
#define RSPI1_SPCMD5_ADDR	( ( volatile uint16_t __evenaccess * )0x000883BA )
#define RSPI1_SPCMD6_ADDR	( ( volatile uint16_t __evenaccess * )0x000883BC )
#define RSPI1_SPCMD7_ADDR	( ( volatile uint16_t __evenaccess * )0x000883BE )
#define RSPI2_SPCMD0_ADDR	( ( volatile uint16_t __evenaccess * )0x000883D0 )
#define RSPI2_SPCMD1_ADDR	( ( volatile uint16_t __evenaccess * )0x000883D2 )
#define RSPI2_SPCMD2_ADDR	( ( volatile uint16_t __evenaccess * )0x000883D4 )
#define RSPI2_SPCMD3_ADDR	( ( volatile uint16_t __evenaccess * )0x000883D6 )
#define RSPI2_SPCMD4_ADDR	( ( volatile uint16_t __evenaccess * )0x000883D8 )
#define RSPI2_SPCMD5_ADDR	( ( volatile uint16_t __evenaccess * )0x000883DA )
#define RSPI2_SPCMD6_ADDR	( ( volatile uint16_t __evenaccess * )0x000883DC )
#define RSPI2_SPCMD7_ADDR	( ( volatile uint16_t __evenaccess * )0x000883DE )
#define RSPI_SPCMD_SPB_OFFSET	(8)
#define RSPI_SPCMD_SPB_MASK (0xF << RSPI_SPCMD_SPB_OFFSET)

/*
 *  UART関連の定義
 *
 *  pdicのrx600/rx630_uart.cで使用する．
 */
/*
 *  シリアルI/Oの個数
 */
#define TNUM_SIOP	( 2 )

#endif	/* TOPPERS_RX630_H */

